import re

from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``el_GR`` locale."""

    uppercase_letters = "ABEZHIKMNOPTYX"

    license_formats = (
        "??? ####",
        "?? ####",
    )

    def license_plate(self) -> str:
        """Generate a license plate."""
        temp = re.sub(
            r"\?",
            lambda x: self.random_element(self.uppercase_letters),
            self.random_element(self.license_formats),
        )
        return self.numerify(temp)



from .. import Provider as CurrencyProvider


class Provider(CurrencyProvider):
    # Format: (code, name)
    # Source: https://az.wikipedia.org/wiki/M%C3%B6vcud_valyutalar%C4%B1n_siyah%C4%B1s%C4%B1
    currencies = (
        ("USD", "ABŞ dolları"),
        ("ALL", "Albaniya leki"),
        ("AOA", "Anqola kvanzası"),
        ("ARS", "Argentina pesosu"),
        ("AWG", "Aruba florini"),
        ("EUR", "Avro"),
        ("AUD", "Avstraliya dolları"),
        ("AZN", "Azərbaycan manatı"),
        ("BSD", "Baham dolları"),
        ("BDT", "Banqladeş takası"),
        ("BBD", "Barbados dolları"),
        ("BZD", "Beliz dolları"),
        ("BMD", "Bermud dolları"),
        ("MMK", "Birma kyatı"),
        ("BOB", "Boliviya bolivianosu"),
        ("BGN", "Bolqarıstan levi"),
        ("BAM", "Bosniya və Herseqovina konvertasiya olunan markası"),
        ("BWP", "Botsvana pulası"),
        ("BRL", "Braziliya realı"),
        ("GBP", "Britaniya funtu"),
        ("GBP", "Britaniya funtu[C]"),
        ("BND", "Bruney dolları"),
        ("BIF", "Burundi frankı"),
        ("BTN", "Butan nqultrumu"),
        ("AED", "BƏƏ dirhəmi"),
        ("BHD", "Bəhreyn dinarı"),
        ("XPF", "CFP frankı"),
        ("JEP", "Cersi funtu"),
        ("DJF", "Cibuti frankı"),
        ("GIP", "Cəbəllütariq funtu"),
        ("ZAR", "Cənubi Afrika randı"),
        ("KRW", "Cənubi Koreya vonası"),
        ("SSP", "Cənubi Sudan funtu"),
        ("DKK", "Danimarka kronu"),
        ("PRB", "Dnestryanı rublu"),
        ("DOP", "Dominikan pesosu"),
        ("ETB", "Efiopiya birri"),
        ("ERN", "Eritreya nakfası"),
        ("AMD", "Ermənistan dramı"),
        ("SZL", "Esvatini lilangenisi"),
        ("FJD", "Fici dolları"),
        ("PHP", "Filippin pesosu"),
        ("FKP", "Folklend adaları funtu"),
        ("(yoxdur)", "Gernsi funtu"),
        ("GGP", "Gernsi funtu"),
        ("GEL", "Gürcüstan larisi"),
        ("HTG", "Haiti qurdu"),
        ("INR", "Hindistan rupisi"),
        ("HNL", "Honduras lempirası"),
        ("HKD", "Honkonq dolları"),
        ("CVE", "Kabo-Verde eskudosu"),
        ("KHR", "Kamboca rieli"),
        ("CAD", "Kanada dolları"),
        ("KYD", "Kayman adaları dolları"),
        ("KES", "Keniya şillinqi"),
        ("COP", "Kolumbiya pesosu"),
        ("KMF", "Komor frankı"),
        ("CDF", "Konqo frankı"),
        ("CRC", "Kosta-Rika kolonu"),
        ("CUC", "Kuba konvertasiya olunan pesosu"),
        ("CUP", "Kuba pesosu"),
        ("BYN", "Köhnə Belarus rublu"),
        ("KWD", "Küveyt dinarı"),
        ("LAK", "Laos kipi"),
        ("LSL", "Lesoto lotisi"),
        ("LRD", "Liberiya dolları"),
        ("LBP", "Livan funtu"),
        ("LYD", "Liviya dinarı"),
        ("HUF", "Macarıstan forinti"),
        ("MOP", "Makao patakası"),
        ("MKD", "Makedoniya denarı"),
        ("MGA", "Malaqasi ariarisi"),
        ("MWK", "Malavi kvaçası"),
        ("MYR", "Malayziya ringgiti"),
        ("MVR", "Maldiv rufiyası"),
        ("MUR", "Mavriki rupisi"),
        ("MRO", "Mavritaniya ugiya"),
        ("MRO", "Mavritaniya ugiyası"),
        ("MXN", "Meksika pesosu"),
        ("IMP", "Men funtu"),
        ("EGP", "Misir funtu"),
        ("MDL", "Moldova leyi"),
        ("MNT", "Monqolustan tuqriki"),
        ("MZN", "Mozambik metikalı"),
        ("SHP", "Müqəddəs Yelena funtu"),
        ("MAD", "Mərakeş dirhəmi"),
        ("XAF", "Mərkəzi Afrika AMİ frankı"),
        ("NAD", "Namibiya dolları"),
        ("NPR", "Nepal rupisi"),
        ("ANG", "Niderland Antil adaları quldeni"),
        ("NGN", "Nigeriya nayrası"),
        ("NIO", "Nikaraqua kordobası"),
        ("NOK", "Norveç kronu"),
        ("OMR", "Oman rialı"),
        ("PKR", "Pakistan rupisi"),
        ("PAB", "Panama balboası"),
        ("PGK", "Papua-Yeni Qvineya kinası"),
        ("PYG", "Paraqvay quaranisi"),
        ("PLN", "Polşa zlotısı"),
        ("GMD", "Qambiya dalasisi"),
        ("GHS", "Qana sedisi"),
        ("GYD", "Qayana dolları"),
        ("KZT", "Qazaxıstan tengəsi"),
        ("GTQ", "Qvatemala ketsalı"),
        ("GNF", "Qvineya frankı"),
        ("KGS", "Qırğız somu"),
        ("XOF", "Qərbi Afrika AMİ frankı"),
        ("QAR", "Qətər rialı"),
        ("RWF", "Ruanda frankı"),
        ("RON", "Rumıniya leyi"),
        ("RUB", "Rus rublu"),
        ("RUB", "Rusiya rublu"),
        ("WST", "Samoa talası"),
        ("STD", "San-Tome və Prinsipi dobrası"),
        ("RSD", "Serbiya dinarı"),
        ("SCR", "Seyşel rupisi"),
        ("SGD", "Sinqapur dolları"),
        ("SBD", "Solomon adaları dolları"),
        ("SOS", "Somali şillinqi"),
        ("SDG", "Sudan funtu"),
        ("SRD", "Surinam dolları"),
        ("SYP", "Suriya funtu"),
        ("SLL", "Syerra-Leone leonesi"),
        ("SAR", "Səudiyyə Ərəbistanı rialı"),
        ("TJS", "Tacikistan somonisi"),
        ("THB", "Tailand bahtı"),
        ("TZS", "Tanzaniya şillinqi"),
        ("TOP", "Tonqa paanqası"),
        ("TTD", "Trinidad və Tobaqo dolları"),
        ("TND", "Tunis dinarı"),
        ("TVD", "Tuvalu dolları"),
        ("TRY", "Türk lirəsi"),
        ("TMT", "Türkmənistan manatı"),
        ("UAH", "Ukrayna qrivnası"),
        ("UGX", "Uqanda şillinqi"),
        ("UYU", "Uruqvay pesosu"),
        ("VUV", "Vanuatu vatusu"),
        ("VEF", "Venesuela bolivarı"),
        ("VND", "Vyetnam donqu"),
        ("HRK", "Xorvatiya kunası"),
        ("JMD", "Yamayka dolları"),
        ("JPY", "Yapon yeni"),
        ("BYR", "Yeni Belarus rublu"),
        ("PEN", "Yeni Peru solu"),
        ("TWD", "Yeni Tayvan dolları"),
        ("NZD", "Yeni Zelandiya dolları"),
        ("ILS", "Yeni İsrail şekeli"),
        ("YER", "Yəmən rialı"),
        ("ZMW", "Zambiya kvaçası"),
        ("CZK", "Çex kronu"),
        ("CLP", "Çili pesosu"),
        ("CNY", "Çin yuanı"),
        ("UZS", "Özbək somu"),
        ("IDR", "İndoneziya rupiası"),
        ("JOD", "İordaniya dinarı"),
        ("IRR", "İran rialı"),
        ("IQD", "İraq dinarı"),
        ("ISK", "İslandiya kronası"),
        ("SEK", "İsveç kronu"),
        ("CHF", "İsveçrə frankı"),
        ("KPW", "Şimali Koreya vonası"),
        ("LKR", "Şri-Lanka rupisi"),
        ("XCD", "Şərqi Karib dolları"),
        ("AFN", "Əfqanıstan əfqanisi"),
        ("DZD", "Əlcəzair dinarı"),
    )

    price_formats = ["#,##", "%#,##", "%##,##", "%.###,##", "%#.###,##"]

    def pricetag(self):
        return self.numerify(self.random_element(self.price_formats)) + "\N{no-break space}AZN"



from collections import OrderedDict

from .. import Provider as AddressProvider


class Provider(AddressProvider):
    street_suffixes = OrderedDict(
        (
            ("utca", 0.75),
            ("út", 0.1),
            ("tér", 0.1),
            ("köz", 0.001),
            ("körút", 0.001),
            ("sétány", 0.001),
        )
    )

    street_name_formats = (
        "{{frequent_street_name}} {{street_suffix}}",
        "{{real_city_name}}i {{street_suffix}}",
        "{{city_part}}{{city_suffix}}i {{street_suffix}}",
        "{{city_prefix}}{{city_part}}i {{street_suffix}}",
    )

    #   Currently deprecated.
    #   secondary_address_formats = ("#.em #.", "##. em. #.")

    city_formats = (
        "{{city_prefix}}{{city_part}}{{city_suffix}}",
        "{{city_part}}{{city_suffix}}",
        "{{real_city_name}}",
    )

    street_address_formats = ("{{street_name}} {{building_number}}",)

    address_formats = ("{{street_address}}\n{{postcode}} {{city}}",)

    frequent_street_names = (
        "Ady Endre",
        "Dózsa György",
        "Petőfi",
        "Petőfi Sándor",
        "Arany János",
        "Béke",
        "Szabadság",
        "Kossuth",
        "József Attila",
    )

    # The 'real city name' generator includes a number of real cities of
    # Hungary that no generator could feasibly dispense. Please note that the
    # post code generator is, at this point, not capable of generating a
    # fitting post code. In Hungary, post codes are determined by the county of
    # the place (see the county generator), and for this reason, often there
    # will be a discrepancy. A patch is in the works - until then, use
    # Wikipedia to resolve postcode issues.
    #
    # This generator was created by collecting the 30 largest Hungarian places
    # by population, based on the Hungarian Gazetteer generated with effect as
    # of 01 January 2016 (http://www.ksh.hu/docs/hun/hnk/hnk_2016.pdf).

    real_city_names = (
        "Budapest",
        "Debrecen",
        "Szeged",
        "Miskolc",
        "Pécs",
        "Győr",
        "Nyíregyháza",
        "Kecskemét",
        "Székesfehérvár",
        "Szombathely",
        "Szolnok",
        "Tatabánya",
        "Érd",
        "Kaposvár",
        "Sopron",
        "Veszprém",
        "Békéscsaba",
        "Zalaegerszeg",
        "Eger",
        "Nagykanizsa",
        "Dunaújváros",
        "Hódmezővásárhely",
        "Dunakeszi",
        "Szigetszentmiklós",
        "Cegléd",
        "Baja",
        "Salgótarján",
        "Ózd",
        "Vác",
        "Mosonmagyaróvár",
    )

    city_prefs = (
        "kis",
        "nagy",
        "szent",
        "duna",
        "tisza",
        "alsó",
        "felső",
        "belső",
        "bakony",
        "vác",
        "mező",
        "nyék",
        "nyír",
        "balaton",
        "borsod",
        "buda",
        "hajdú",
        "kun",
        "moson",
        "pilis",
        "új",
        "egyházas",
        "dráva",
        "magyar",
        "mátra",
        "somogy",
        "lajos",
        "bács",
        "békés",
        "puszta",
        "orosz",
        "rác",
        "szerb",
        "német",
        "török",
    )

    city_parts = (
        "híd",
        "györgy",
        "mindszent",
        "kereszt",
        "márton",
        "hát",
        "hetven",
        "mellék",
        "tamási",
        "tapolca",
        "fürdő",
        "liget",
        "szék",
        "tót",
        "",
    )

    city_suffixes = (
        "háza",
        "németi",
        "devecser",
        "fa",
        "nádasd",
        "apáti",
        "falu",
        "falva",
        "vég",
        "vár",
        "vára",
        "várad",
        "hida",
        "kövesd",
        "bánya",
        "halas",
        "berény",
        "kőrös",
        "haraszti",
        "város",
    )

    counties = (
        "Bács-Kiskun",
        "Baranya",
        "Békés",
        "Borsod-Abaúj-Zemplén",
        "Csongrád",
        "Fejér",
        "Győr-Moson-Sopron",
        "Hajdú-Bihar",
        "Heves",
        "Jász-Nagykun-Szolnok",
        "Komárom-Esztergom",
        "Nógrád",
        "Pest",
        "Somogy",
        "Szabolcs-Szatmár-Bereg",
        "Tolna",
        "Vas",
        "Veszprém",
        "Zala",
    )

    countries = (
        "Afganisztán",
        "Aland-szigetek",
        "Albánia",
        "Algéria",
        "Amerikai Szamoa",
        "Amerikai Virgin-szigetek",
        "Andorra",
        "Angola",
        "Anguilla",
        "Antarktisz",
        "Antigua és Barbuda",
        "Apostoli Szentszék",
        "Argentína",
        "Aruba",
        "Ausztrália",
        "Ausztria",
        "Amerikai Egyesült Államok Külső Szigetei",
        "Azerbajdzsán",
        "Bahama-szigetek",
        "Bahrein",
        "Banglades",
        "Barbados",
        "Fehéroroszország",
        "Belgium",
        "Belize",
        "Benin",
        "Bermuda",
        "Bhután",
        "Bissa -Guinea",
        "Bolívia",
        "Bosznia-Hercegovina",
        "Botswana",
        "Bouvet-sziget",
        "Brazília",
        "Brit Indiai-óceáni Terület",
        "Brit Virgin - szigetek",
        "Brunei",
        "Bulgária",
        "Burkina Faso",
        "Burundi",
        "Chile",
        "Ciprus",
        "Comore-szigetek",
        "Cook-szigetek",
        "Costa Rica",
        "Csád",
        "Csehország",
        "Dánia",
        "Dél-Afrika",
        "Dél-Korea",
        "Dominika",
        "Dominikai Köztársaság",
        "Dzsibuti",
        "Ecuador",
        "Egyenlítői-Guinea",
        "Egyesült Államok",
        "Egyesült Arab Emírségek",
        "Egyesült Királyság",
        "Egyiptom",
        "Elefántcsontpart",
        "Eritrea",
        "Északi Mariana-szigetek",
        "Észak-Korea",
        "Észak-Macedónia",
        "Észtország",
        "Etiópia",
        "Falkland-szigetek",
        "Feröer szigetek",
        "Fidzsi-szigetek",
        "Finnország",
        "Francia Déli Területek",
        "Francia Guyana",
        "Francia Polinézia",
        "Franciaország",
        "Fülöp-szigetek",
        "Gabon",
        "Gambia",
        "Ghána",
        "Gibraltár",
        "Görögország",
        "Grenada",
        "Grönland",
        "Grúzia",
        "Guadeloupe",
        "Guam",
        "Guatemala",
        "Guinea",
        "Guyana",
        "Haiti",
        "Holland Antillák",
        "Hollandia",
        "Honduras",
        "Hongkong",
        "Horvátország",
        "India",
        "Indonézia",
        "Irak",
        "Irán",
        "Írország",
        "Izland",
        "Izrael",
        "Jamaica",
        "Japán",
        "Jemen",
        "Jordánia",
        "Kajmán-szigetek",
        "Kambodzsa",
        "Kamerun",
        "Kanada",
        "Karácsony-sziget",
        "Katar",
        "Kazahsztán",
        "Kelet-Timor",
        "Kenya",
        "Kína",
        "Kirgizisztán",
        "Kiribati",
        "Keeling-szigetek",
        "Kolumbia",
        "Kongó",
        "Kongói Demokratikus Köztársaság",
        "Közép-afrikai Köztársaság",
        "Kuba",
        "Kuvait",
        "Laosz",
        "Lengyelország",
        "Lesotho",
        "Lettország",
        "Libanon",
        "Libéria",
        "Líbia",
        "Liechtenstein",
        "Litvánia",
        "Luxemburg",
        "Madagaszkár",
        "Magyarország",
        "Makaó",
        "Malajzia",
        "Malawi",
        "Maldív-szigetek",
        "Mali",
        "Málta",
        "Marokkó",
        "Marshall-szigetek",
        "Martinique",
        "Mauritánia",
        "Mauritius",
        "Mayotte",
        "Mexikó",
        "Mianmar",
        "Mikronézia",
        "Moldova",
        "Monaco",
        "Mongólia",
        "Montenegró",
        "Montserrat",
        "Mozambik",
        "Namíbia",
        "Nauru",
        "Németország",
        "Nepál",
        "Nicaragua",
        "Niger",
        "Nigéria",
        "Niue",
        "Norfolk-sziget",
        "Norvégia",
        "Nyugat-Szahara",
        "Olaszország",
        "Omán",
        "Oroszország",
        "Örményország",
        "Pakisztán",
        "Palau",
        "Panama",
        "Pápua",
        "Új-Guinea",
        "Paraguay",
        "Peru",
        "Pitcairn-szigetek",
        "Portugália",
        "Puerto Rico",
        "Réunion",
        "Románia",
        "Ruanda",
        "Saint Kitts és Nevis",
        "Saint Lucia",
        "Saint-Pierre és Miquelon",
        "Saint Vincent és Grenadine-szigetek",
        "Salamon-szigetek",
        "Salvador",
        "San Marino",
        "São Tomé és Príncipe",
        "Seychelle-szigetek",
        "Sierra Leone",
        "Spanyolország",
        "Srí Lanka",
        "Suriname",
        "Svájc",
        "Svalbard szigetek",
        "Svédország",
        "Szamoa",
        "Szaúdi-Arábia",
        "Szenegál",
        "Szent Ilona",
        "Szerbia",
        "Szingapúr",
        "Szíria",
        "Szlovákia",
        "Szlovénia",
        "Szomália",
        "Szudán",
        "Szváziföld",
        "Tádzsikisztán",
        "Tajvan",
        "Tanzánia",
        "Thaiföld",
        "Togo",
        "Tokelau-szigetek",
        "Tonga",
        "Törökország",
        "Trinidad és Tobago",
        "Tunézia",
        "Turks- és Caicos-szigetek",
        "Tuvalu",
        "Türkmenisztán",
        "Uganda",
        "Új-Kaledónia",
        "Új-Zéland",
        "Ukrajna",
        "Uruguay",
        "Üzbegisztán",
        "Vanuatu",
        "Venezuela",
        "Vietnam",
        "Wallis és Futuna",
        "Zambia",
        "Zimbabwe",
        "Zöld-foki szigetek",
    )

    def administrative_unit(self) -> str:
        return self.random_element(self.counties)

    county = administrative_unit

    def street_address_with_county(self) -> str:
        return f"{self.street_address()}\n{self.county()} megye\n{self.postcode()} {self.city().capitalize()}"

    def city_prefix(self) -> str:
        return self.random_element(self.city_prefs)

    def city_part(self) -> str:
        return self.random_element(self.city_parts)

    def real_city_name(self) -> str:
        return self.random_element(self.real_city_names)

    def frequent_street_name(self) -> str:
        return self.random_element(self.frequent_street_names)

    def postcode(self) -> str:
        return (
            f"H-{super().random_digit_not_null()}{super().random_digit()}"
            f"{super().random_digit()}{super().random_digit()}"
        )

    def street_name(self) -> str:
        return super().street_name().capitalize()

    def building_number(self) -> str:
        numeric_part = super().random_int(1, 250)
        return str(numeric_part) + "."

    # method added to fix #1996:
    # for hu_Hu locale city_part could be first or second component of city,
    # so city_parts tuple should contain lower-cased strings. Thus city might be lower-cased and should be capitalized
    def city(self) -> str:
        """
        :example: 'Györgyháza'
        """
        pattern: str = self.random_element(self.city_formats)
        return self.generator.parse(pattern).capitalize()



from collections import OrderedDict

from .. import Provider as AddressProvider


class Provider(AddressProvider):
    city_suffixes = [
        "berg",
        "borg",
        "by",
        "bø",
        "dal",
        "eid",
        "fjell",
        "fjord",
        "foss",
        "grunn",
        "hamn",
        "havn",
        "helle",
        "mark",
        "nes",
        "odden",
        "sand",
        "sjøen",
        "stad",
        "strand",
        "strøm",
        "sund",
        "vik",
        "vær",
        "våg",
        "ø",
        "øy",
        "ås",
    ]
    street_suffixes = [
        "alléen",
        "bakken",
        "berget",
        "bråten",
        "eggen",
        "engen",
        "ekra",
        "faret",
        "flata",
        "gata",
        "gjerdet",
        "grenda",
        "gropa",
        "hagen",
        "haugen",
        "havna",
        "holtet",
        "høgda",
        "jordet",
        "kollen",
        "kroken",
        "lia",
        "lunden",
        "lyngen",
        "løkka",
        "marka",
        "moen",
        "myra",
        "plassen",
        "ringen",
        "roa",
        "røa",
        "skogen",
        "skrenten",
        "spranget",
        "stien",
        "stranda",
        "stubben",
        "stykket",
        "svingen",
        "tjernet",
        "toppen",
        "tunet",
        "vollen",
        "vika",
        "åsen",
    ]
    city_formats = ["{{first_name}}{{city_suffix}}", "{{last_name}}"]
    street_name_formats = [
        "{{last_name}}{{street_suffix}}",
    ]
    street_address_formats = ("{{street_name}} {{building_number}}",)
    address_formats = ("{{street_address}}, {{postcode}} {{city}}",)
    building_number_formats = ("%", "%", "%", "%?", "##", "##", "##?", "###")
    building_number_suffixes = OrderedDict(
        [
            ("A", 0.2),
            ("B", 0.2),
            ("C", 0.2),
            ("D", 0.1),
            ("E", 0.1),
            ("F", 0.1),
            ("G", 0.05),
            ("H", 0.05),
        ]
    )
    postcode_formats = ("####",)

    def building_number(self) -> str:
        suffix: str = self.random_element(self.building_number_suffixes)
        return self.numerify(self.random_element(self.building_number_formats)).replace("?", suffix)

    def city_suffix(self) -> str:
        return self.random_element(self.city_suffixes)

    def street_suffix(self) -> str:
        return self.random_element(self.street_suffixes)



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_male}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{first_name_female}} {{last_name}}",
        "{{prefix_male}} {{first_name_male}} {{last_name}}",
        "{{prefix_female}} {{first_name_female}} {{last_name}}",
        "{{first_name_male}} {{last_name}}, {{suffix}}",
        "{{first_name_female}} {{last_name}}, {{suffix}}",
        "{{prefix_male}} {{first_name_male}} {{last_name}}, {{suffix}}",
        "{{prefix_female}} {{first_name_female}} {{last_name}}, {{suffix}}",
    )

    # From http://www.nama.web.id/search.php?gender=male&origin=Indonesia+-+Jawa&letter=&submit=Search
    # via
    # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
    first_names_male = (
        "Abyasa",
        "Ade",
        "Adhiarja",
        "Adiarja",
        "Adika",
        "Adikara",
        "Adinata",
        "Aditya",
        "Agus",
        "Ajiman",
        "Ajimat",
        "Ajimin",
        "Ajiono",
        "Akarsana",
        "Alambana",
        "Among",
        "Anggabaya",
        "Anom",
        "Argono",
        "Aris",
        "Arta",
        "Artanto",
        "Artawan",
        "Arsipatra",
        "Asirwada",
        "Asirwanda",
        "Aslijan",
        "Asmadi",
        "Asman",
        "Asmianto",
        "Asmuni",
        "Aswani",
        "Atma",
        "Atmaja",
        "Bagas",
        "Bagiya",
        "Bagus",
        "Bagya",
        "Bahuraksa",
        "Bahuwarna",
        "Bahuwirya",
        "Bajragin",
        "Bakda",
        "Bakiadi",
        "Bakianto",
        "Bakidin",
        "Bakijan",
        "Bakiman",
        "Bakiono",
        "Bakti",
        "Baktiadi",
        "Baktianto",
        "Baktiono",
        "Bala",
        "Balamantri",
        "Balangga",
        "Balapati",
        "Balidin",
        "Balijan",
        "Bambang",
        "Banara",
        "Banawa",
        "Banawi",
        "Bancar",
        "Budi",
        "Cagak",
        "Cager",
        "Cahyadi",
        "Cahyanto",
        "Cahya",
        "Cahyo",
        "Cahyono",
        "Caket",
        "Cakrabirawa",
        "Cakrabuana",
        "Cakrajiya",
        "Cakrawala",
        "Cakrawangsa",
        "Candra",
        "Chandra",
        "Candrakanta",
        "Capa",
        "Caraka",
        "Carub",
        "Catur",
        "Caturangga",
        "Cawisadi",
        "Cawisono",
        "Cawuk",
        "Cayadi",
        "Cecep",
        "Cemani",
        "Cemeti",
        "Cemplunk",
        "Cengkal",
        "Cengkir",
        "Dacin",
        "Dadap",
        "Dadi",
        "Dagel",
        "Daliman",
        "Dalimin",
        "Daliono",
        "Damar",
        "Damu",
        "Danang",
        "Daniswara",
        "Danu",
        "Danuja",
        "Dariati",
        "Darijan",
        "Darimin",
        "Darmaji",
        "Darman",
        "Darmana",
        "Darmanto",
        "Darsirah",
        "Dartono",
        "Daru",
        "Daruna",
        "Daryani",
        "Dasa",
        "Digdaya",
        "Dimas",
        "Dimaz",
        "Dipa",
        "Dirja",
        "Drajat",
        "Dwi",
        "Dono",
        "Dodo",
        "Edi",
        "Eka",
        "Elon",
        "Eluh",
        "Eman",
        "Emas",
        "Embuh",
        "Emong",
        "Empluk",
        "Endra",
        "Enteng",
        "Estiawan",
        "Estiono",
        "Eko",
        "Edi",
        "Edison",
        "Edward",
        "Elvin",
        "Erik",
        "Emil",
        "Ega",
        "Emin",
        "Eja",
        "Gada",
        "Gadang",
        "Gaduh",
        "Gaiman",
        "Galak",
        "Galang",
        "Galar",
        "Galih",
        "Galiono",
        "Galuh",
        "Galur",
        "Gaman",
        "Gamani",
        "Gamanto",
        "Gambira",
        "Gamblang",
        "Ganda",
        "Gandewa",
        "Gandi",
        "Gandi",
        "Ganep",
        "Gangsa",
        "Gangsar",
        "Ganjaran",
        "Gantar",
        "Gara",
        "Garan",
        "Garang",
        "Garda",
        "Gatot",
        "Gatra",
        "Gilang",
        "Galih",
        "Ghani",
        "Gading",
        "Hairyanto",
        "Hardana",
        "Hardi",
        "Harimurti",
        "Harja",
        "Harjasa",
        "Harjaya",
        "Harjo",
        "Harsana",
        "Harsanto",
        "Harsaya",
        "Hartaka",
        "Hartana",
        "Harto",
        "Hasta",
        "Heru",
        "Himawan",
        "Hadi",
        "Halim",
        "Hasim",
        "Hasan",
        "Hendra",
        "Hendri",
        "Heryanto",
        "Hamzah",
        "Hari",
        "Imam",
        "Indra",
        "Irwan",
        "Irsad",
        "Ikhsan",
        "Irfan",
        "Ian",
        "Ibrahim",
        "Ibrani",
        "Ismail",
        "Irnanto",
        "Ilyas",
        "Ibun",
        "Ivan",
        "Ikin",
        "Ihsan",
        "Jabal",
        "Jaeman",
        "Jaga",
        "Jagapati",
        "Jagaraga",
        "Jail",
        "Jaiman",
        "Jaka",
        "Jarwa",
        "Jarwadi",
        "Jarwi",
        "Jasmani",
        "Jaswadi",
        "Jati",
        "Jatmiko",
        "Jaya",
        "Jayadi",
        "Jayeng",
        "Jinawi",
        "Jindra",
        "Joko",
        "Jumadi",
        "Jumari",
        "Jamal",
        "Jamil",
        "Jais",
        "Jefri",
        "Johan",
        "Jono",
        "Kacung",
        "Kajen",
        "Kambali",
        "Kamidin",
        "Kariman",
        "Karja",
        "Karma",
        "Karman",
        "Karna",
        "Karsa",
        "Karsana",
        "Karta",
        "Kasiran",
        "Kasusra",
        "Kawaca",
        "Kawaya",
        "Kayun",
        "Kemba",
        "Kenari",
        "Kenes",
        "Kuncara",
        "Kunthara",
        "Kusuma",
        "Kadir",
        "Kala",
        "Kalim",
        "Kurnia",
        "Kanda",
        "Kardi",
        "Karya",
        "Kasim",
        "Kairav",
        "Kenzie",
        "Kemal",
        "Kamal",
        "Koko",
        "Labuh",
        "Laksana",
        "Lamar",
        "Lanang",
        "Langgeng",
        "Lanjar",
        "Lantar",
        "Lega",
        "Legawa",
        "Lembah",
        "Liman",
        "Limar",
        "Luhung",
        "Lukita",
        "Luluh",
        "Lulut",
        "Lurhur",
        "Luwar",
        "Luwes",
        "Latif",
        "Lasmanto",
        "Lukman",
        "Luthfi",
        "Leo",
        "Luis",
        "Lutfan",
        "Lasmono",
        "Laswi",
        "Mahesa",
        "Makara",
        "Makuta",
        "Manah",
        "Maras",
        "Margana",
        "Mariadi",
        "Marsudi",
        "Martaka",
        "Martana",
        "Martani",
        "Marwata",
        "Maryadi",
        "Maryanto",
        "Mitra",
        "Mujur",
        "Mulya",
        "Mulyanto",
        "Mulyono",
        "Mumpuni",
        "Muni",
        "Mursita",
        "Murti",
        "Mustika",
        "Maman",
        "Mahmud",
        "Mahdi",
        "Mahfud",
        "Malik",
        "Muhammad",
        "Mustofa",
        "Marsito",
        "Mursinin",
        "Nalar",
        "Naradi",
        "Nardi",
        "Niyaga",
        "Nrima",
        "Nugraha",
        "Nyana",
        "Narji",
        "Nasab",
        "Nasrullah",
        "Nasim",
        "Najib",
        "Najam",
        "Nyoman",
        "Olga",
        "Ozy",
        "Omar",
        "Opan",
        "Oskar",
        "Oman",
        "Okto",
        "Okta",
        "Opung",
        "Paiman",
        "Panca",
        "Pangeran",
        "Pangestu",
        "Pardi",
        "Parman",
        "Perkasa",
        "Praba",
        "Prabu",
        "Prabawa",
        "Prabowo",
        "Prakosa",
        "Pranata",
        "Pranawa",
        "Prasetya",
        "Prasetyo",
        "Prayitna",
        "Prayoga",
        "Prayogo",
        "Purwadi",
        "Purwa",
        "Purwanto",
        "Panji",
        "Pandu",
        "Paiman",
        "Prima",
        "Putu",
        "Raden",
        "Raditya",
        "Raharja",
        "Rama",
        "Rangga",
        "Reksa",
        "Respati",
        "Rusman",
        "Rosman",
        "Rahmat",
        "Rahman",
        "Rendy",
        "Reza",
        "Rizki",
        "Ridwan",
        "Rudi",
        "Raden",
        "Radit",
        "Radika",
        "Rafi",
        "Rafid",
        "Raihan",
        "Salman",
        "Saadat",
        "Saiful",
        "Surya",
        "Slamet",
        "Samsul",
        "Soleh",
        "Simon",
        "Sabar",
        "Sabri",
        "Sidiq",
        "Satya",
        "Setya",
        "Saka",
        "Sakti",
        "Taswir",
        "Tedi",
        "Teddy",
        "Taufan",
        "Taufik",
        "Tomi",
        "Tasnim",
        "Teguh",
        "Tasdik",
        "Timbul",
        "Tirta",
        "Tirtayasa",
        "Tri",
        "Tugiman",
        "Umar",
        "Usman",
        "Uda",
        "Umay",
        "Unggul",
        "Utama",
        "Umaya",
        "Upik",
        "Viktor",
        "Vino",
        "Vinsen",
        "Vero",
        "Vega",
        "Viman",
        "Virman",
        "Wahyu",
        "Wira",
        "Wisnu",
        "Wadi",
        "Wardi",
        "Warji",
        "Waluyo",
        "Wakiman",
        "Wage",
        "Wardaya",
        "Warsa",
        "Warsita",
        "Warta",
        "Wasis",
        "Wawan",
        "Xanana",
        "Yahya",
        "Yusuf",
        "Yosef",
        "Yono",
        "Yoga",
    )

    # From http://namafb.com/2010/08/12/top-1000-nama-populer-indonesia/
    # via
    # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
    first_names_female = (
        "Ade",
        "Agnes",
        "Ajeng",
        "Amalia",
        "Anita",
        "Ayu",
        "Aisyah",
        "Ana",
        "Ami",
        "Ani",
        "Azalea",
        "Aurora",
        "Alika",
        "Anastasia",
        "Amelia",
        "Almira",
        "Bella",
        "Betania",
        "Belinda",
        "Citra",
        "Cindy",
        "Chelsea",
        "Clara",
        "Cornelia",
        "Cinta",
        "Cinthia",
        "Ciaobella",
        "Cici",
        "Carla",
        "Calista",
        "Devi",
        "Dewi",
        "Dian",
        "Diah",
        "Diana",
        "Dina",
        "Dinda",
        "Dalima",
        "Eka",
        "Eva",
        "Endah",
        "Elisa",
        "Eli",
        "Ella",
        "Ellis",
        "Elma",
        "Elvina",
        "Fitria",
        "Fitriani",
        "Febi",
        "Faizah",
        "Farah",
        "Farhunnisa",
        "Fathonah",
        "Gabriella",
        "Gasti",
        "Gawati",
        "Genta",
        "Ghaliyati",
        "Gina",
        "Gilda",
        "Halima",
        "Hesti",
        "Hilda",
        "Hafshah",
        "Hamima",
        "Hana",
        "Hani",
        "Hasna",
        "Humaira",
        "Ika",
        "Indah",
        "Intan",
        "Irma",
        "Icha",
        "Ida",
        "Ifa",
        "Ilsa",
        "Ina",
        "Ira",
        "Iriana",
        "Jamalia",
        "Janet",
        "Jane",
        "Julia",
        "Juli",
        "Jessica",
        "Jasmin",
        "Jelita",
        "Kamaria",
        "Kamila",
        "Kani",
        "Karen",
        "Karimah",
        "Kartika",
        "Kasiyah",
        "Keisha",
        "Kezia",
        "Kiandra",
        "Kayla",
        "Kania",
        "Lala",
        "Lalita",
        "Latika",
        "Laila",
        "Laras",
        "Lidya",
        "Lili",
        "Lintang",
        "Maria",
        "Mala",
        "Maya",
        "Maida",
        "Maimunah",
        "Melinda",
        "Mila",
        "Mutia",
        "Michelle",
        "Malika",
        "Nadia",
        "Nadine",
        "Nabila",
        "Natalia",
        "Novi",
        "Nova",
        "Nurul",
        "Nilam",
        "Najwa",
        "Olivia",
        "Ophelia",
        "Oni",
        "Oliva",
        "Padma",
        "Putri",
        "Paramita",
        "Paris",
        "Patricia",
        "Paulin",
        "Puput",
        "Puji",
        "Pia",
        "Puspa",
        "Puti",
        "Putri",
        "Padmi",
        "Qori",
        "Queen",
        "Ratih",
        "Ratna",
        "Restu",
        "Rini",
        "Rika",
        "Rina",
        "Rahayu",
        "Rahmi",
        "Rachel",
        "Rahmi",
        "Raisa",
        "Raina",
        "Sarah",
        "Sari",
        "Siti",
        "Siska",
        "Suci",
        "Syahrini",
        "Septi",
        "Sadina",
        "Safina",
        "Sakura",
        "Salimah",
        "Salwa",
        "Salsabila",
        "Samiah",
        "Shania",
        "Sabrina",
        "Silvia",
        "Shakila",
        "Talia",
        "Tami",
        "Tira",
        "Tiara",
        "Titin",
        "Tania",
        "Tina",
        "Tantri",
        "Tari",
        "Titi",
        "Uchita",
        "Unjani",
        "Ulya",
        "Uli",
        "Ulva",
        "Umi",
        "Usyi",
        "Vanya",
        "Vanesa",
        "Vivi",
        "Vera",
        "Vicky",
        "Victoria",
        "Violet",
        "Winda",
        "Widya",
        "Wulan",
        "Wirda",
        "Wani",
        "Yani",
        "Yessi",
        "Yulia",
        "Yuliana",
        "Yuni",
        "Yunita",
        "Yance",
        "Zahra",
        "Zalindra",
        "Zaenab",
        "Zulfa",
        "Zizi",
        "Zulaikha",
        "Zamira",
        "Zelda",
        "Zelaya",
    )

    first_names = first_names_male + first_names_female

    # From http://namafb.com/2010/08/12/top-1000-nama-populer-indonesia/
    # From http://id.wikipedia.org/wiki/Daftar_marga_suku_Batak_di_Toba
    # via
    # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
    last_names_male = (
        "Adriansyah",
        "Ardianto",
        "Anggriawan",
        "Budiman",
        "Budiyanto",
        "Damanik",
        "Dongoran",
        "Dabukke",
        "Firmansyah",
        "Firgantoro",
        "Gunarto",
        "Gunawan",
        "Hardiansyah",
        "Habibi",
        "Hakim",
        "Halim",
        "Haryanto",
        "Hidayat",
        "Hidayanto",
        "Hutagalung",
        "Hutapea",
        "Hutasoit",
        "Irawan",
        "Iswahyudi",
        "Kuswoyo",
        "Januar",
        "Jailani",
        "Kurniawan",
        "Kusumo",
        "Latupono",
        "Lazuardi",
        "Maheswara",
        "Mahendra",
        "Mustofa",
        "Mansur",
        "Mandala",
        "Megantara",
        "Maulana",
        "Maryadi",
        "Mangunsong",
        "Manullang",
        "Marpaung",
        "Marbun",
        "Narpati",
        "Natsir",
        "Nugroho",
        "Najmudin",
        "Nashiruddin",
        "Nainggolan",
        "Nababan",
        "Napitupulu",
        "Pangestu",
        "Putra",
        "Pranowo",
        "Prabowo",
        "Pratama",
        "Prasetya",
        "Prasetyo",
        "Pradana",
        "Pradipta",
        "Prakasa",
        "Permadi",
        "Prasasta",
        "Prayoga",
        "Ramadan",
        "Rajasa",
        "Rajata",
        "Saptono",
        "Santoso",
        "Saputra",
        "Saefullah",
        "Setiawan",
        "Suryono",
        "Suwarno",
        "Siregar",
        "Sihombing",
        "Salahudin",
        "Sihombing",
        "Samosir",
        "Saragih",
        "Sihotang",
        "Simanjuntak",
        "Sinaga",
        "Simbolon",
        "Sitompul",
        "Sitorus",
        "Sirait",
        "Siregar",
        "Situmorang",
        "Tampubolon",
        "Thamrin",
        "Tamba",
        "Tarihoran",
        "Utama",
        "Uwais",
        "Wahyudin",
        "Waluyo",
        "Wibowo",
        "Winarno",
        "Wibisono",
        "Wijaya",
        "Widodo",
        "Wacana",
        "Waskita",
        "Wasita",
        "Zulkarnain",
    )

    # From http://namafb.com/2010/08/12/top-1000-nama-populer-indonesia/
    # via
    # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
    last_names_female = (
        "Agustina",
        "Andriani",
        "Anggraini",
        "Aryani",
        "Astuti",
        "Fujiati",
        "Farida",
        "Handayani",
        "Hassanah",
        "Hartati",
        "Hasanah",
        "Haryanti",
        "Hariyah",
        "Hastuti",
        "Halimah",
        "Kusmawati",
        "Kuswandari",
        "Laksmiwati",
        "Laksita",
        "Lestari",
        "Lailasari",
        "Mandasari",
        "Mardhiyah",
        "Mayasari",
        "Melani",
        "Mulyani",
        "Maryati",
        "Nurdiyanti",
        "Novitasari",
        "Nuraini",
        "Nasyidah",
        "Nasyiah",
        "Namaga",
        "Palastri",
        "Pudjiastuti",
        "Puspasari",
        "Puspita",
        "Purwanti",
        "Pratiwi",
        "Purnawati",
        "Pertiwi",
        "Permata",
        "Prastuti",
        "Padmasari",
        "Rahmawati",
        "Rahayu",
        "Riyanti",
        "Rahimah",
        "Suartini",
        "Sudiati",
        "Suryatmi",
        "Susanti",
        "Safitri",
        "Oktaviani",
        "Utami",
        "Usamah",
        "Usada",
        "Uyainah",
        "Yuniar",
        "Yuliarti",
        "Yulianti",
        "Yolanda",
        "Wahyuni",
        "Wijayanti",
        "Widiastuti",
        "Winarsih",
        "Wulandari",
        "Wastuti",
        "Zulaika",
    )

    last_names = last_names_male + last_names_female

    prefixes_male = (
        "Dt.",
        "R.",
        "R.M.",
        "Sutan",
        "T.",
        "Tgk.",
        # From http://id.wikipedia.org/wiki/Gelar_akademik
        # via
        # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
        # plus noble titles
        "dr.",
        "drg.",
        "Dr.",
        "Drs.",
        "Ir.",
        "H.",
        "KH.",
    )

    prefixes_female = (
        "Cut",
        "Puti",
        "R.",
        "R.A.",
        "Tgk.",
        # From http://id.wikipedia.org/wiki/Gelar_akademik
        # via
        # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
        # plus noble titles
        "dr.",
        "drg.",
        "Dr.",
        "Drs.",
        "Ir.",
        "Hj.",
    )

    # From http://id.wikipedia.org/wiki/Gelar_akademik
    # via
    # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
    suffixes = (
        "S.Ked",
        "S.Gz",
        "S.Pt",
        "S.IP",
        "S.E.I",
        "S.E.",
        "S.Kom",
        "S.H.",
        "S.T.",
        "S.Pd",
        "S.Psi",
        "S.I.Kom",
        "S.Sos",
        "S.Farm",
        "M.M.",
        "M.Kom.",
        "M.TI.",
        "M.Pd",
        "M.Farm",
        "M.Ak",
    )



import datetime

from .. import Provider as SsnProvider


class Provider(SsnProvider):
    def ssn(self, min_age: int = 0, max_age: int = 105, artificial: bool = False) -> str:
        """
        Returns 11 character Finnish personal identity code (Henkilötunnus,
        HETU, Swedish: Personbeteckning). This function assigns random
        gender to person.

        HETU consists of eleven characters of the form DDMMYYCZZZQ, where
        DDMMYY is the date of birth, C the century sign, ZZZ the individual
        number and Q the control character (checksum). The sign for the
        century is either + (1800–1899), - (1900–1999), or A (2000–2099).
        The individual number ZZZ is odd for males and even for females.
        For people born in Finland its range is 002-899
        (larger numbers may be used in special cases).
        An example of a valid code is 311280-888Y.

        https://en.wikipedia.org/wiki/National_identification_number#Finland
        """

        def _checksum(hetu):
            checksum_characters = "0123456789ABCDEFHJKLMNPRSTUVWXY"
            return checksum_characters[int(hetu) % 31]

        if min_age == max_age:
            age = datetime.timedelta(days=min_age * 365)
        else:
            age = datetime.timedelta(days=self.generator.random.randrange(min_age * 365, max_age * 365))
        birthday = datetime.date.today() - age
        hetu_date = "%02d%02d%s" % (
            birthday.day,
            birthday.month,
            str(birthday.year)[-2:],
        )
        range = (900, 999) if artificial is True else (2, 899)
        suffix = str(self.generator.random.randrange(*range)).zfill(3)
        checksum = _checksum(hetu_date + suffix)
        separator = self._get_century_code(birthday.year)
        hetu = "".join([hetu_date, separator, suffix, checksum])
        return hetu

    @staticmethod
    def _get_century_code(year: int) -> str:
        """Returns the century code for a given year"""
        if 2000 <= year < 3000:
            separator = "A"
        elif 1900 <= year < 2000:
            separator = "-"
        elif 1800 <= year < 1900:
            separator = "+"
        else:
            raise ValueError("Finnish SSN do not support people born before the year 1800 or after the year 2999")
        return separator

    vat_id_formats = ("FI########",)

    def vat_id(self) -> str:
        """
        http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
        :return: A random Finnish VAT ID
        """
        return self.bothify(self.random_element(self.vat_id_formats))



"""TEST NOTES:

The following tests cover cases where a ``faker_session_locale`` fixture was defined
by the user as well as a user-defined ``faker_locale`` autouse fixture. In this setup,
the value of ``faker_session_locale`` will be ignored, since the plugin's session level
``Faker`` instance will not be used. Each test will instead generate a new instance using
the value of ``faker_locale``. These new instances will be still seeded in accordance to
the plugin's seeding rules.
"""

from random import Random

import pytest

from faker.contrib.pytest.plugin import DEFAULT_SEED

_CHANGED_LOCALE = ["it_IT"]


@pytest.fixture(autouse=True)
def faker_locale():
    return _CHANGED_LOCALE


@pytest.fixture()
def faker_seed():
    return 4761


def test_no_injection(_session_faker, faker):
    random = Random(DEFAULT_SEED)
    assert faker != _session_faker
    assert faker.locales == _CHANGED_LOCALE
    assert faker.random != random
    assert faker.random.getstate() == random.getstate()


def test_inject_faker_seed(_session_faker, faker, faker_seed):
    random = Random(faker_seed)
    assert faker != _session_faker
    assert faker.locales == _CHANGED_LOCALE
    assert faker.random != random
    assert faker.random.getstate() == random.getstate()



from .. import Provider as AddressProvider


class Provider(AddressProvider):
    address_formats = (
        "{{prefecture}}{{city}}{{town}}{{chome}}{{ban}}{{gou}}",
        "{{prefecture}}{{city}}{{town}}{{chome}}{{ban}}{{gou}} {{town}}{{building_name}}{{building_number}}",
        "{{prefecture}}{{city}}{{town}}{{chome}}{{ban}}{{gou}} {{building_name}}{{town}}{{building_number}}",
    )

    building_number_formats = ("###",)

    countries = (
        "アフガニスタン",
        "アルバニア",
        "アルジェリア",
        "アメリカ領サモア",
        "アンドラ",
        "アンゴラ",
        "アンギラ",
        "南極大陸",
        "アンティグアバーブーダ",
        "アルゼンチン",
        "アルメニア",
        "アルバ",
        "オーストラリア",
        "オーストリア",
        "アゼルバイジャン",
        "バハマ",
        "バーレーン",
        "バングラデシュ",
        "バルバドス",
        "ベラルーシ",
        "ベルギー",
        "ベリーズ",
        "ベナン",
        "バミューダ島",
        "ブータン",
        "ボリビア",
        "ボスニア・ヘルツェゴビナ",
        "ボツワナ",
        "ブーベ島",
        "ブラジル",
        "イギリス領インド洋地域",
        "イギリス領ヴァージン諸島",
        "ブルネイ",
        "ブルガリア",
        "ブルキナファソ",
        "ブルンジ",
        "カンボジア",
        "カメルーン",
        "カナダ",
        "カーボベルデ",
        "ケイマン諸島",
        "中央アフリカ共和国",
        "チャド",
        "チリ",
        "中国",
        "クリスマス島",
        "ココス諸島",
        "コロンビア",
        "コモロ",
        "コンゴ共和国",
        "クック諸島",
        "コスタリカ",
        "コートジボワール",
        "クロアチア",
        "キューバ",
        "キプロス共和国",
        "チェコ共和国",
        "デンマーク",
        "ジブチ共和国",
        "ドミニカ国",
        "ドミニカ共和国",
        "エクアドル",
        "エジプト",
        "エルサルバドル",
        "赤道ギニア共和国",
        "エリトリア",
        "エストニア",
        "エチオピア",
        "フェロー諸島",
        "フォークランド諸島",
        "フィジー共和国",
        "フィンランド",
        "フランス",
        "フランス領ギアナ",
        "フランス領ポリネシア",
        "フランス領極南諸島",
        "ガボン",
        "ガンビア",
        "グルジア",
        "ドイツ",
        "ガーナ",
        "ジブラルタル",
        "ギリシャ",
        "グリーンランド",
        "グレナダ",
        "グアドループ",
        "グアム",
        "グアテマラ",
        "ガーンジー",
        "ギニア",
        "ギニアビサウ",
        "ガイアナ",
        "ハイチ",
        "ハード島とマクドナルド諸島",
        "バチカン市国",
        "ホンジュラス",
        "香港",
        "ハンガリー",
        "アイスランド",
        "インド",
        "インドネシア",
        "イラン",
        "イラク",
        "アイルランド共和国",
        "マン島",
        "イスラエル",
        "イタリア",
        "ジャマイカ",
        "日本",
        "ジャージー島",
        "ヨルダン",
        "カザフスタン",
        "ケニア",
        "キリバス",
        "朝鮮",
        "韓国",
        "クウェート",
        "キルギス共和国",
        "ラオス人民民主共和国",
        "ラトビア",
        "レバノン",
        "レソト",
        "リベリア",
        "リビア国",
        "リヒテンシュタイン",
        "リトアニア",
        "ルクセンブルク",
        "マカオ",
        "北マケドニア共和国",
        "マダガスカル",
        "マラウィ",
        "マレーシア",
        "モルディブ",
        "マリ",
        "マルタ共和国",
        "マーシャル諸島",
        "マルティニーク",
        "モーリタニア・イスラム共和国",
        "モーリシャス",
        "マヨット",
        "メキシコ",
        "ミクロネシア連邦",
        "モルドバ共和国",
        "モナコ公国",
        "モンゴル",
        "モンテネグロ共和国",
        "モントセラト",
        "モロッコ",
        "モザンビーク",
        "ミャンマー",
        "ナミビア",
        "ナウル",
        "ネパール",
        "オランダ領アンティル",
        "オランダ",
        "ニューカレドニア",
        "ニュージーランド",
        "ニカラグア",
        "ニジェール",
        "ナイジェリア",
        "ニース",
        "ノーフォーク島",
        "北マリアナ諸島",
        "ノルウェー",
        "オマーン",
        "パキスタン",
        "パラオ",
        "パレスチナ自治区",
        "パナマ",
        "パプアニューギニア",
        "パラグアイ",
        "ペルー",
        "フィリピン",
        "ピトケアン諸島",
        "ポーランド",
        "ポルトガル",
        "プエルトリコ",
        "カタール",
        "レユニオン",
        "ルーマニア",
        "ロシア",
        "ルワンダ",
        "サン・バルテルミー島",
        "セントヘレナ",
        "セントクリストファー・ネイビス連邦",
        "セントルシア",
        "セント・マーチン島",
        "サンピエール島・ミクロン島",
        "セントビンセント・グレナディーン",
        "サモア",
        "サンマリノ",
        "サントメプリンシペ",
        "サウジアラビア",
        "セネガル",
        "セルビア",
        "セイシェル",
        "シエラレオネ",
        "シンガポール",
        "スロバキア",
        "スロベニア",
        "ソロモン諸島",
        "ソマリア",
        "南アフリカ共和国",
        "サウスジョージア・サウスサンドウィッチ諸島",
        "スペイン",
        "スリランカ",
        "スーダン",
        "スリナム",
        "スヴァールバル諸島およびヤンマイエン島",
        "スワジランド王国",
        "スウェーデン",
        "スイス",
        "シリア",
        "台湾",
        "タジキスタン共和国",
        "タンザニア",
        "タイ",
        "東ティモール",
        "トーゴ",
        "トケラウ",
        "トンガ",
        "トリニダード・トバゴ",
        "チュニジア",
        "トルコ",
        "トルクメニスタン",
        "タークス・カイコス諸島",
        "ツバル",
        "ウガンダ",
        "ウクライナ",
        "アラブ首長国連邦",
        "イギリス",
        "アメリカ合衆国",
        "合衆国領有小離島",
        "アメリカ領ヴァージン諸島",
        "ウルグアイ",
        "ウズベキスタン",
        "バヌアツ",
        "ベネズエラ",
        "ベトナム",
        "ウォリス・フツナ",
        "西サハラ",
        "イエメン",
        "ザンビア",
        "ジンバブエ",
    )

    prefectures = (
        "北海道",
        "青森県",
        "岩手県",
        "宮城県",
        "秋田県",
        "山形県",
        "福島県",
        "茨城県",
        "栃木県",
        "群馬県",
        "埼玉県",
        "千葉県",
        "東京都",
        "神奈川県",
        "新潟県",
        "富山県",
        "石川県",
        "福井県",
        "山梨県",
        "長野県",
        "岐阜県",
        "静岡県",
        "愛知県",
        "三重県",
        "滋賀県",
        "京都府",
        "大阪府",
        "兵庫県",
        "奈良県",
        "和歌山県",
        "鳥取県",
        "島根県",
        "岡山県",
        "広島県",
        "山口県",
        "徳島県",
        "香川県",
        "愛媛県",
        "高知県",
        "福岡県",
        "佐賀県",
        "長崎県",
        "熊本県",
        "大分県",
        "宮崎県",
        "鹿児島県",
        "沖縄県",
    )

    cities = (
        "八千代市",
        "我孫子市",
        "鴨川市",
        "鎌ケ谷市",
        "君津市",
        "富津市",
        "浦安市",
        "四街道市",
        "袖ケ浦市",
        "八街市",
        "印西市",
        "白井市",
        "富里市",
        "南房総市",
        "匝瑳市",
        "香取市",
        "山武市",
        "いすみ市",
        "大網白里市",
        "印旛郡酒々井町",
        "印旛郡印旛村",
        "印旛郡本埜村",
        "印旛郡栄町",
        "香取郡神崎町",
        "香取郡多古町",
        "香取郡東庄町",
        "山武郡九十九里町",
        "山武郡芝山町",
        "山武郡横芝光町",
        "長生郡一宮町",
        "長生郡睦沢町",
        "長生郡長生村",
        "長生郡白子町",
        "長生郡長柄町",
        "長生郡長南町",
        "夷隅郡大多喜町",
        "夷隅郡御宿町",
        "安房郡鋸南町",
        "千代田区",
        "中央区",
        "港区",
        "新宿区",
        "文京区",
        "台東区",
        "墨田区",
        "江東区",
        "品川区",
        "目黒区",
        "大田区",
        "世田谷区",
        "渋谷区",
        "中野区",
        "杉並区",
        "豊島区",
        "北区",
        "荒川区",
        "板橋区",
        "練馬区",
        "足立区",
        "葛飾区",
        "江戸川区",
        "八王子市",
        "立川市",
        "武蔵野市",
        "三鷹市",
        "青梅市",
        "府中市",
        "昭島市",
        "調布市",
        "町田市",
        "小金井市",
        "小平市",
        "日野市",
        "東村山市",
        "国分寺市",
        "国立市",
        "福生市",
        "狛江市",
        "東大和市",
        "清瀬市",
        "東久留米市",
        "武蔵村山市",
        "多摩市",
        "稲城市",
        "羽村市",
        "あきる野市",
        "西東京市",
        "西多摩郡瑞穂町",
        "西多摩郡日の出町",
        "西多摩郡檜原村",
        "西多摩郡奥多摩町",
        "大島町",
        "利島村",
        "新島村",
        "神津島村",
        "三宅島三宅村",
        "御蔵島村",
        "八丈島八丈町",
        "青ヶ島村",
        "小笠原村",
        "横浜市鶴見区",
        "横浜市神奈川区",
        "横浜市西区",
        "横浜市中区",
        "横浜市南区",
        "横浜市保土ケ谷区",
        "横浜市磯子区",
        "横浜市金沢区",
        "横浜市港北区",
        "横浜市戸塚区",
        "横浜市港南区",
        "横浜市旭区",
        "横浜市緑区",
        "横浜市瀬谷区",
        "横浜市栄区",
        "横浜市泉区",
        "横浜市青葉区",
        "横浜市都筑区",
        "川崎市川崎区",
        "川崎市幸区",
        "川崎市中原区",
        "川崎市高津区",
        "川崎市多摩区",
        "川崎市宮前区",
    )

    towns = (
        "丹勢",
        "中宮祠",
        "手岡",
        "東和町",
        "所野",
        "土沢",
        "独鈷沢",
        "轟",
        "土呂部",
        "中小来川",
        "長畑",
        "中鉢石町",
        "中三依",
        "西小来川",
        "西川",
        "日光",
        "東三島",
        "東大和町",
        "蟇沼",
        "二つ室",
        "方京",
        "細竹",
        "前弥六",
        "前弥六南町",
        "松浦町",
        "南赤田",
        "南郷屋",
        "美原町",
        "無栗屋",
        "睦",
        "百村",
        "箭坪",
        "山中新田",
        "油井",
        "湯宮",
        "豊町",
        "湯本塩原",
        "横林",
        "四区町",
        "渡辺",
        "氏家",
        "氏家新田",
        "卯の里",
        "小入",
        "大中",
        "押上",
        "柿木沢",
        "柿木沢新田",
        "鍛冶ケ沢",
        "上高野",
        "上吉羽",
        "木立",
        "権現堂",
        "幸手",
        "下宇和田",
        "下吉羽",
        "神明内",
        "外国府間",
        "千塚",
        "天神島",
        "戸島",
        "中川崎",
        "長間",
        "西関宿",
        "花島",
        "平須賀",
        "細野",
        "松石",
        "太田ヶ谷",
        "上広谷",
        "五味ヶ谷",
        "脚折",
        "脚折町",
        "鶴ヶ丘",
        "羽折町",
        "藤金",
        "九段南",
        "皇居外苑",
        "麹町",
        "猿楽町",
        "外神田",
        "西神田",
        "隼町",
        "東神田",
        "一ツ橋",
        "日比谷公園",
        "平河町",
        "丸の内",
        "丸の内ＪＰタワー",
        "四番町",
        "六番町",
        "明石町",
        "勝どき",
        "京橋",
        "月島",
        "北青山",
        "港南",
        "芝浦",
        "芝公園",
        "芝大門",
        "白金",
        "白金台",
        "台場",
        "高輪",
        "虎ノ門",
        "虎ノ門虎ノ門ヒルズ森タワー",
        "大京町",
        "高田馬場",
        "箪笥町",
        "津久戸町",
        "筑土八幡町",
        "戸塚町",
        "富久町",
        "戸山",
        "秋葉原",
        "浅草",
        "浅草橋",
        "池之端",
        "今戸",
        "入谷",
        "上野公園",
        "上野桜木",
        "雷門",
        "北上野",
        "蔵前",
        "千束",
        "台東",
        "鳥越",
        "西浅草",
        "日本堤",
        "橋場",
        "花川戸",
        "東浅草",
        "東上野",
        "松が谷",
        "三筋",
        "三ノ輪",
        "元浅草",
        "竜泉",
        "吾妻橋",
    )

    building_names = (
        "パレス",
        "ハイツ",
        "コーポ",
        "アーバン",
        "クレスト",
        "パーク",
        "シティ",
        "シャルム",
        "コート",
    )

    def administrative_unit(self) -> str:
        """
        :example: '東京都'
        """
        return self.random_element(self.prefectures)

    prefecture = administrative_unit

    def city(self) -> str:
        """
        :example: '台東区'
        """
        return self.random_element(self.cities)

    def town(self) -> str:
        """
        :example: '浅草'
        """
        return self.random_element(self.towns)

    def chome(self) -> str:
        """
        :example: '1丁目'
        """
        return "%d丁目" % self.generator.random.randint(1, 42)

    def ban(self) -> str:
        """
        :example: '3番'
        """
        return "%d番" % self.generator.random.randint(1, 27)

    def gou(self) -> str:
        """
        :example: '10号'
        """
        return "%d号" % self.generator.random.randint(1, 20)

    def building_name(self) -> str:
        """
        :example: 'コーポ芝浦'
        """
        return self.random_element(self.building_names)

    def postcode(self) -> str:
        """
        :example: '101-1212'
        """
        return "%03d-%04d" % (
            self.generator.random.randint(0, 999),
            self.generator.random.randint(0, 9999),
        )

    def zipcode(self) -> str:
        return self.postcode()



from collections import OrderedDict

from .. import Provider as ColorProvider

localized = True


class Provider(ColorProvider):
    """Implement color provider for ``bg_BG`` locale."""

    all_colors = OrderedDict(
        (
            ("Антично-бяло", "#FAEBD7"),
            ("Аквамарин", "#7FFFD4"),
            ("Лазурно", "#F0FFFF"),
            ("Бежово", "#F5F5DC"),
            ("Черно", "#000000"),
            ("Синьо", "#0000FF"),
            ("Синьо-виолетовo", "#8A2BE2"),
            ("Кафявo", "#A52A2A"),
            ("Шоколадовo", "#D2691E"),
            ("Корал", "#FF7F50"),
            ("Метличино синьо", "#6495ED"),
            ("Малиново", "#DC143C"),
            ("Тъмносиньо", "#00008B"),
            ("Тъмноциан", "#008B8B"),
            ("Тъмносуво", "#A9A9A9"),
            ("Тъмнозелено", "#006400"),
            ("Тъмно маслинено зелено", "#BDB76B"),
            ("Тъмнооранжево", "#FF8C00"),
            ("Тъмночервено", "#8B0000"),
            ("Тъмнотюркоазено", "#00CED1"),
            ("Тъмновиолетово", "#9400D3"),
            ("Тъмнорозово", "#FF1493"),
            ("Бледо сиво", "#696969"),
            ("Фуксия", "#FF00FF"),
            ("Златно", "#FFD700"),
            ("Сребърно", "#808080"),
            ("Зелено", "#008000"),
            ("Жълто-зелено", "#ADFF2F"),
            ("Ярко-розово", "#FF69B4"),
            ("Индиго", "#4B0082"),
            ("Слонова кост", "#FFFFF0"),
            ("Маслинено зелено", "#F0E68C"),
            ("Розовато-лавандулово", "#FFF0F5"),
            ("Светлосиньо", "#ADD8E6"),
            ("Светло-небесносино", "#E0FFFF"),
            ("Светлосиво", "#D3D3D3"),
            ("Светлозелено", "#90EE90"),
            ("Светлорозово", "#FFB6C1"),
            ("Небесносиньо", "#87CEFA"),
            ("Светложълто", "#FFFFE0"),
            ("Кестеняво", "#800000"),
            ("Оранжево", "#FFA500"),
            ("Оранжево-червено", "#FF4500"),
            ("Бледозелено", "#98FB98"),
            ("Бледотюркоазно", "#AFEEEE"),
            ("Розово", "#FFC0CB"),
            ("Сливово розово", "#DDA0DD"),
            ("Пурпурно", "#800080"),
            ("Червено", "#FF0000"),
            ("Циан", "#2E8B57"),
            ("Сребърно", "#C0C0C0"),
            ("Тюркоазено", "#40E0D0"),
            ("Виолетово", "#EE82EE"),
            ("Бяло", "#FFFFFF"),
            ("Жълто", "#FFFF00"),
            ("Жълто-зелено", "#9ACD32"),
        )
    )

    safe_colors = (
        "черно",
        "бордо",
        "зелено",
        "маслинено зелено",
        "пурпурно",
        "циан",
        "лайм",
        "синьо",
        "сребърно",
        "сиво",
        "жълто",
        "фуксия",
        "бяло",
    )



import re

from typing import Pattern

from faker.providers.phone_number import Provider as PhoneNumberProvider
from faker.providers.phone_number.en_PH import Provider as EnPhPhoneNumberProvider


class TestPhoneNumber:
    """Test phone number provider methods"""

    def test_country_calling_code(self, faker, num_samples):
        for _ in range(num_samples):
            cc = faker.country_calling_code()
            assert cc in PhoneNumberProvider.country_calling_codes

    def test_msisdn(self, faker, num_samples):
        for _ in range(num_samples):
            msisdn = faker.msisdn()
            assert isinstance(msisdn, str)
            assert len(msisdn) == 13
            assert msisdn.isdigit()


class TestAzAz:
    """Test az_AZ phone number provider methods"""

    @classmethod
    def setup_class(cls):
        cls.cellphone_patterns = re.compile(
            r"\+994\d{9}|0\d{2}-\d{3}-\d{2}-\d{2}|0\d{2} \d{3} \d{2} \d{2}",
        )
        cls.landline_patterns = re.compile(
            r"0\d{2} \d{3} \d{2} \d{2}",
        )

    def test_phone_number(self, faker, num_samples):
        for _ in range(num_samples):
            phone_number = faker.phone_number()
            assert isinstance(phone_number, str)
            assert self.cellphone_patterns.fullmatch(phone_number) or self.landline_patterns.fullmatch(phone_number)

    def test_cellphone_number(self, faker, num_samples):
        for _ in range(num_samples):
            cellphone_number = faker.cellphone_number()
            assert isinstance(cellphone_number, str)
            assert self.cellphone_patterns.fullmatch(cellphone_number)

    def test_landline_number(self, faker, num_samples):
        for _ in range(num_samples):
            landline_number = faker.landline_number()
            assert isinstance(landline_number, str)
            assert self.landline_patterns.fullmatch(landline_number)


class TestJaJp:
    """Test ja_JP phone number provider methods"""

    def test_phone_number(self, faker, num_samples):
        for _ in range(num_samples):
            pattern: Pattern = re.compile(r"(?:0[789]0|\d{2})-\d{4}-\d{4}")
            phone_number = faker.phone_number()
            assert pattern.fullmatch(phone_number)


class TestCsCz:
    """Test cs_CZ phone number provider methods"""

    def test_phone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(r"^(00420|\+420)? ?[6-7][0-9]{2} ?[0-9]{3} ?[0-9]{3}$")
        for _ in range(num_samples):
            phone_number = faker.phone_number()
            assert pattern.fullmatch(phone_number)


class TestSkSk:
    """Test sk_SK phone number provider methods"""

    def test_phone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(
            r"(^(00421|\+421)? ?[2] ?[0-9]{8}$)|"
            r"(^(00421|\+421)? ?[3-5][0-9] ?[0-9]{3} ?[0-9]{4}$)|"
            r"(^(00421|\+421)? ?[9][0-9]{2} ?[0-9]{3} ?[0-9]{3}$)"
        )

        for _ in range(num_samples):
            phone_number = faker.phone_number()
            assert pattern.fullmatch(phone_number)


class TestPtBr:
    """Test pt_BR phone number provider methods"""

    def test_phone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(
            r"(?:\+55 )?" r"(?:[1-8]1|84|\((?:0[1-8]1|084)\))" r" \d{4}[ -]\d{4}|" r"\d{4}?[ -]\d{3}[ -]\d{4}",
        )
        for _ in range(num_samples):
            phone_number = faker.phone_number()
            assert pattern.fullmatch(phone_number)

    def test_msisdn(self, faker, num_samples):
        pattern: Pattern = re.compile(r"55(?:[1-8]19|849)\d{8}")
        for _ in range(num_samples):
            msisdn = faker.msisdn()
            assert pattern.fullmatch(msisdn)

    def test_cellphone(self, faker, num_samples):
        pattern: Pattern = re.compile(
            r"(?:\+55 )?" r"(?:\d{2}|\(0?\d{2}\))" r" 9 ?\d{4}[ -]\d{4}",
        )
        for _ in range(num_samples):
            cellphone = faker.cellphone_number()
            assert pattern.fullmatch(cellphone)

    def test_service_phone(self, faker, num_samples):
        pattern: Pattern = re.compile(r"1(?:0|2|5|8|9)?(?:[0-9])")
        for _ in range(num_samples):
            service = faker.service_phone_number()
            assert pattern.fullmatch(service)


class TestHuHu:
    """Test hu_HU phone number provider methods"""

    def test_phone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(
            r"(?:" r"\+36 \d{2} |" r"\(06\)\d{2}/|" r"\(\d{2}\)/|" r"\d{2}/|" r"06-\d{1,2}/" r")\d{3}[- ]\d{4}",
        )
        for _ in range(num_samples):
            phone_number = faker.phone_number()
            assert isinstance(phone_number, str)
            assert pattern.fullmatch(phone_number)


class TestThTh:
    """Test th_TH phone number provider methods"""

    def test_phone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(
            # leading zero or internaional code
            r"((\+66)|\+66[ -]?\(0\)|0)[ -]?"
            # landline or mobile
            r"([23457][ -]?(\d[ -]?){6}\d|[689][ -]?(\d[ -]?){7}\d)"
            # extension
            r"([ ]?(x|ext|ต่อ)[\.]?[ ]?\d{1,5})?",
            re.IGNORECASE,
        )
        for _ in range(num_samples):
            phone_number = faker.phone_number()
            assert isinstance(phone_number, str)
            assert pattern.fullmatch(phone_number)


class TestHyAm:
    """Test hy_AM phone number provider methods"""

    def test_phone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(
            r"(?:[23]\d{2}-|\([23]\d{2}\) |[23]\d{2}\.)\d{5}|" r"(?:(?:10|9\d)-|\((?:10|9\d)\) |(?:10|9\d)\.)\d{6}",
        )
        for _ in range(num_samples):
            phone_number = faker.phone_number()
            assert isinstance(phone_number, str)
            assert pattern.fullmatch(phone_number)


class TestEnPh:
    """Test en_PH phone number provider methods"""

    @classmethod
    def setup_class(cls):
        cls.mobile_number_pattern: Pattern = re.compile(r"^(?:0|\+63)(\d+)-\d{3}-\d{4}$")
        cls.area2_landline_number_pattern: Pattern = re.compile(r"^(?:0|\+63)2-(\d{4})-\d{4}")
        cls.non_area2_landline_number_pattern: Pattern = re.compile(r"^(?:0|\+63)(\d{2})-(\d{3})-\d{4}")
        cls.globe_mobile_number_prefixes = EnPhPhoneNumberProvider.globe_mobile_number_prefixes
        cls.smart_mobile_number_prefixes = EnPhPhoneNumberProvider.smart_mobile_number_prefixes
        cls.sun_mobile_number_prefixes = EnPhPhoneNumberProvider.sun_mobile_number_prefixes
        cls.mobile_number_prefixes = (
            cls.globe_mobile_number_prefixes + cls.smart_mobile_number_prefixes + cls.sun_mobile_number_prefixes
        )
        cls.bayantel_landline_identifiers = EnPhPhoneNumberProvider.bayantel_landline_identifiers
        cls.misc_landline_identifiers = EnPhPhoneNumberProvider.misc_landline_identifiers
        cls.non_area2_landline_area_codes = EnPhPhoneNumberProvider.non_area2_landline_area_codes

    def test_globe_mobile_number(self, faker, num_samples):
        for _ in range(num_samples):
            number = faker.globe_mobile_number()
            match = self.mobile_number_pattern.match(number)
            assert match and match.group(1) in self.globe_mobile_number_prefixes

    def test_smart_mobile_number(self, faker, num_samples):
        for _ in range(num_samples):
            number = faker.smart_mobile_number()
            match = self.mobile_number_pattern.match(number)
            assert match and match.group(1) in self.smart_mobile_number_prefixes

    def test_sun_mobile_number(self, faker, num_samples):
        for _ in range(num_samples):
            number = faker.sun_mobile_number()
            match = self.mobile_number_pattern.match(number)
            assert match and match.group(1) in self.sun_mobile_number_prefixes

    def test_mobile_number(self, faker, num_samples):
        for _ in range(num_samples):
            number = faker.mobile_number()
            match = self.mobile_number_pattern.match(number)
            assert match and match.group(1) in self.mobile_number_prefixes

    def test_globe_area2_landline_number(self, faker, num_samples):
        for _ in range(num_samples):
            number = faker.globe_area2_landline_number()
            match = self.area2_landline_number_pattern.match(number)
            assert match and match.group(1).startswith("7")

    def test_pldt_area2_landline_number(self, faker, num_samples):
        for _ in range(num_samples):
            number = faker.pldt_area2_landline_number()
            match = self.area2_landline_number_pattern.match(number)
            assert match and match.group(1).startswith("8")

    def test_bayantel_area2_landline_number(self, faker, num_samples):
        for _ in range(num_samples):
            number = faker.bayantel_area2_landline_number()
            match = self.area2_landline_number_pattern.match(number)
            assert match and match.group(1) in self.bayantel_landline_identifiers

    def test_misc_area2_landline_number(self, faker, num_samples):
        for _ in range(num_samples):
            number = faker.misc_area2_landline_number()
            match = self.area2_landline_number_pattern.match(number)
            assert match and match.group(1) in self.misc_landline_identifiers

    def test_area2_landline_number(self, faker, num_samples):
        for _ in range(num_samples):
            number = faker.area2_landline_number()
            match = self.area2_landline_number_pattern.match(number)
            assert match and any(
                [
                    match.group(1).startswith("7"),
                    match.group(1).startswith("8"),
                    match.group(1) in self.bayantel_landline_identifiers,
                    match.group(1) in self.misc_landline_identifiers,
                ]
            )

    def test_non_area2_landline_number(self, faker, num_samples):
        for _ in range(num_samples):
            number = faker.non_area2_landline_number()
            match = self.non_area2_landline_number_pattern.match(number)
            assert match and match.group(1) in self.non_area2_landline_area_codes

    def test_landline_number(self, faker, num_samples):
        for _ in range(num_samples):
            number = faker.landline_number()
            area2_match = self.area2_landline_number_pattern.match(number)
            non_area2_match = self.non_area2_landline_number_pattern.match(number)
            assert area2_match or non_area2_match
            if area2_match:
                assert any(
                    [
                        area2_match.group(1).startswith("7"),
                        area2_match.group(1).startswith("8"),
                        area2_match.group(1) in self.bayantel_landline_identifiers,
                        area2_match.group(1) in self.misc_landline_identifiers,
                    ]
                )
            elif non_area2_match:
                assert non_area2_match.group(1) in self.non_area2_landline_area_codes


class TestFilPh(TestEnPh):
    """Test fil_PH phone number provider methods"""

    pass


class TestTlPh(TestEnPh):
    """Test tl_PH phone number provider methods"""

    pass


class TestTaIn:
    """Test ta_IN phone number provider methods"""

    def test_phone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(
            r"\+91 \d{3} ?\d{7}|" r"0\d{2}(-)?\d{2}(?(1)| ?)\d{6}",
        )
        for _ in range(num_samples):
            phone_number = faker.phone_number()
            assert pattern.fullmatch(phone_number)


class TestEsCo:
    """Test es_CO phone number provider methods"""

    def test_phone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(
            r"((\+?57|\(\+57\))?60\d)?\d{7}|"
            r"((\+?57 |\(\+57\) )?60\d )?\d{3} \d{2} \d{2}|"
            r"(\+?57|\(\+57\))?3[012]\d{8}|"
            r"(\+?57 |\(\+57\) )?3[012]\d \d{3} \d{2} \d{2}|"
            r"01800\d{7}|"
            r"01 800\d \d{3} \d{3}"
        )
        for _ in range(num_samples):
            phone_number = faker.phone_number()
            assert pattern.fullmatch(phone_number)


class TestEsEs:
    """Test es_ES phone number provider methods"""

    def test_phone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(
            r"\+34 ?(?:7[0-4]|[689]\d)\d" r"(?: \d{3} \d{3}|\d{6}| \d{2} \d{2} \d{2})",
        )
        for _ in range(num_samples):
            phone_number = faker.phone_number()
            assert pattern.fullmatch(phone_number)


class TestArAe:
    """Test ar_AE phone number provider methods"""

    cellphone_pattern: str = r"(?:\+|00)971\s?5[024568]\s?\d{3}\s?\d{4}|" r"05[024568]\s?\d{3}\s?\d{4}"
    telephone_pattern: str = r"(?:\+|00)971\s?[1234679]\s?\d{3}\s?\d{4}|" r"0[1234679]\s?\d{3}\s?\d{4}"
    toll_pattern: str = r"200\d{4}|" r"600\d{6}|" r"800\d{3,7}"
    service_phone_pattern: str = r"9(?:9(?:9|8|7|6|1)|01|22)"

    def test_cellphone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(self.cellphone_pattern)
        for _ in range(num_samples):
            cellphone = faker.cellphone_number()
            assert pattern.fullmatch(cellphone)

    def test_telephone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(self.telephone_pattern)
        for _ in range(num_samples):
            telephone = faker.telephone_number()
            assert pattern.fullmatch(telephone)

    def test_toll_number(self, faker, num_samples):
        pattern: Pattern = re.compile(self.toll_pattern)
        for _ in range(num_samples):
            toll = faker.toll_number()
            assert pattern.fullmatch(toll)

    def test_service_phone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(self.service_phone_pattern)
        for _ in range(num_samples):
            service = faker.service_phone_number()
            assert pattern.fullmatch(service)

    def test_phone_number(self, faker, num_samples):
        pattern: Pattern = re.compile(
            rf"{self.cellphone_pattern}|"
            rf"{self.telephone_pattern}|"
            rf"{self.toll_pattern}|"
            rf"{self.service_phone_pattern}",
        )
        for _ in range(num_samples):
            phone = faker.phone_number()
            assert pattern.fullmatch(phone)


class TestFrFr:
    def test_phone_number(self, faker, num_samples):
        pattern_no_whitespaces: Pattern = re.compile(
            r"^0\d{9}$",
        )
        pattern_no_country_prefix: Pattern = re.compile(
            r"^0\d \d{2} \d{2} \d{2} \d{2}$",
        )
        pattern_country_prefix_1: Pattern = re.compile(
            r"^\+33 \(0\)\d \d{2} \d{2} \d{2} \d{2}$",
        )
        pattern_country_prefix_2: Pattern = re.compile(
            r"^\+33 \d \d{2} \d{2} \d{2} \d{2}$",
        )
        patterns = [
            pattern_no_whitespaces,
            pattern_no_country_prefix,
            pattern_country_prefix_1,
            pattern_country_prefix_2,
        ]
        for _ in range(num_samples):
            phone_number = faker.phone_number()

            pattern_is_found = False

            for pattern in patterns:
                if re.match(pattern, phone_number):
                    pattern_is_found = True
                    break
            assert pattern_is_found


class TestEnUs:
    """Test En_US phone provider methods"""

    def test_basic_phone_number(self, faker, num_samples):
        pattern_no_whitespaces: Pattern = re.compile(
            r"\d{9}",
        )
        pattern_dashes: Pattern = re.compile(r"\d{3}-\d{3}-\d{4}")
        pattern_parens: Pattern = re.compile(r"\(\d{3}\)\d{3}-\d{4}")
        patterns = [pattern_no_whitespaces, pattern_dashes, pattern_parens]
        for _ in range(num_samples):
            phone_number = faker.basic_phone_number()

            pattern_is_found = False
            for pattern in patterns:
                if re.match(pattern, phone_number):
                    pattern_is_found = True
                    break
            assert pattern_is_found



import re

import pytest

from faker.providers.bank import Provider as BankProvider
from faker.providers.bank.az_AZ import Provider as AzAzBankProvider
from faker.providers.bank.cs_CZ import Provider as CsCZBankProvider
from faker.providers.bank.de_CH import Provider as DeChBankProvider
from faker.providers.bank.el_GR import Provider as ElGrBankProvider
from faker.providers.bank.en_GB import Provider as EnGbBankProvider
from faker.providers.bank.en_IE import Provider as EnIeBankProvider
from faker.providers.bank.en_PH import Provider as EnPhBankProvider
from faker.providers.bank.es_AR import Provider as EsArBankProvider
from faker.providers.bank.es_ES import Provider as EsEsBankProvider
from faker.providers.bank.es_MX import Provider as EsMxBankProvider
from faker.providers.bank.es_MX import is_valid_clabe
from faker.providers.bank.fi_FI import Provider as FiFiBankProvider
from faker.providers.bank.fr_FR import Provider as FrFrBankProvider
from faker.providers.bank.nl_BE import Provider as NlBeBankProvider
from faker.providers.bank.no_NO import Provider as NoNoBankProvider
from faker.providers.bank.pl_PL import Provider as PlPlBankProvider
from faker.providers.bank.pt_PT import Provider as PtPtBankProvider
from faker.providers.bank.sk_SK import Provider as SkSKBankProvider
from faker.providers.bank.th_TH import Provider as ThThBankProvider
from faker.providers.bank.tr_TR import Provider as TrTrBankProvider
from faker.providers.bank.uk_UA import Provider as UkUaBankProvider


def is_valid_iban(iban):
    check = iban[4:] + iban[:4]
    check = int("".join(BankProvider.ALPHA.get(c, c) for c in check))
    return check % 97 == 1


def is_valid_aba(aba):
    d = [int(n) for n in aba]
    chkdgt = 3 * (d[0] + d[3] + d[6]) + 7 * (d[1] + d[4] + d[7]) + (d[2] + d[5] + d[8])
    if chkdgt % 10 == 0:
        return True
    return False


class TestAzAz:
    """Test az_AZ bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"[A-Z]{4}\d{20}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == AzAzBankProvider.country_code
            assert re.fullmatch(r"\d{2}[A-Z]{4}\d{20}", iban[2:])

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            bank = faker.bank()
            assert bank in AzAzBankProvider.banks


class TestCsCz:
    """Test cs_CZ bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{20}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == CsCZBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{20}", iban[2:])


class TestSkSk:
    """Test sk_SK bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{20}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == SkSKBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{20}", iban[2:])


class TestNoNo:
    """Test no_NO bank provider"""

    def test_aba(self, faker, num_samples):
        for _ in range(num_samples):
            aba = faker.aba()
            assert len(aba) == 9
            assert is_valid_aba(aba)

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{11}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == NoNoBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{11}", iban[2:])


class TestFaIr:
    """Test fa_IR bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"IR\d{24}", faker.bban())

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"\D{7,25}", faker.bank())


class TestFiFi:
    """Test fi_FI bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{14}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == FiFiBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{14}", iban[2:])


class TestPlPl:
    """Test pl_PL bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{24}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == PlPlBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{24}", iban[2:])


class TestUkUa:
    """Test uk_UA bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{27}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == UkUaBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{27}", iban[2:])


class TestEnGb:
    """Test en_GB bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"[A-Z]{4}\d{14}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == EnGbBankProvider.country_code
            assert re.fullmatch(r"\d{2}[A-Z]{4}\d{14}", iban[2:])


class TestEnIe:
    """Test en_IE bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{23}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == EnIeBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{23}", iban[2:])


class TestRuRu:
    """Test ru_RU bank provider"""

    def test_bic(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"04\d{7,9}", faker.bic())

    def test_correspondent_account(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"301\d{17}", faker.correspondent_account())

    def test_checking_account(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"\d{3}0\d{16}", faker.checking_account())

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"\D{3,41}", faker.bank())


class TestPtPt:
    """Test pt_PT bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{21}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == PtPtBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{21}", iban[2:])


class TestEsEs:
    """Test es_ES bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{20}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == EsEsBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{20}", iban[2:])


class TestEsMx:
    """Test es_MX bank provider"""

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            assert faker.bank() in EsMxBankProvider.banks

    @pytest.mark.parametrize(
        "clabe,validity",
        [
            ("002864631170560203", True),
            ("002864631170560202", False),
            ("00286463117056020", False),
            ("0028646311705602030", False),
            ("00286463117056020A", False),
        ],
        ids=[
            "valid",
            "bad_control_digit",
            "too_short",
            "too_long",
            "non_numeric_characters",
        ],
    )
    def test_clabe_validation(self, clabe, validity):
        assert is_valid_clabe(clabe) is validity

    def test_clabe(self, faker, num_samples):
        for _ in range(num_samples):
            clabe = faker.clabe()
            assert is_valid_clabe(clabe)
            assert int(clabe[:3].lstrip("0")) in EsMxBankProvider.bank_codes

    def test_clabe_bank_code(self, faker, num_samples):
        bank_code = 133
        for _ in range(num_samples):
            clabe = faker.clabe(bank_code=bank_code)
            assert is_valid_clabe(clabe)
            assert int(clabe[:3].lstrip("0")) == bank_code


class TestEsAr:
    """Test es_AR bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"[A-Z]{4}\d{20}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == EsArBankProvider.country_code
            assert re.fullmatch(r"\d{2}[A-Z]{4}\d{20}", iban[2:])


class TestFrFr:
    """Test fr_FR bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{23}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == FrFrBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{23}", iban[2:])


class TestDeDe:
    """Test de_DE bank provider"""

    def test_swift_use_dataset(self, faker, num_samples):
        regex = re.compile("[A-Z]{6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3})?")
        for _ in range(num_samples):
            code = faker.swift(use_dataset=True)
            assert regex.fullmatch(code) is not None


class TestEnPh:
    """Test en_PH bank provider"""

    def test_swift(self, faker, num_samples):
        regex = re.compile("[A-Z]{4}PH[A-Z0-9]{2}(?:[A-Z0-9]{3})?")
        for _ in range(num_samples):
            code = faker.swift()
            assert regex.fullmatch(code) is not None

    def test_swift_invalid_length(self, faker):
        faker.swift(length=8)
        faker.swift(length=11)
        with pytest.raises(AssertionError):
            faker.swift(length=5)

    def test_swift8_use_dataset(self, faker, num_samples):
        for _ in range(num_samples):
            code = faker.swift8(use_dataset=True)
            assert len(code) == 8
            assert code[:4] in EnPhBankProvider.swift_bank_codes
            assert code[4:6] == EnPhBankProvider.country_code
            assert code[6:8] in EnPhBankProvider.swift_location_codes

    def test_swift11_use_dataset(self, faker, num_samples):
        for _ in range(num_samples):
            code = faker.swift11(use_dataset=True)
            assert len(code) == 11
            assert code[:4] in EnPhBankProvider.swift_bank_codes
            assert code[4:6] == EnPhBankProvider.country_code
            assert code[6:8] in EnPhBankProvider.swift_location_codes
            assert code[8:11] in EnPhBankProvider.swift_branch_codes

    def test_swift11_is_primary(self, faker, num_samples):
        for _ in range(num_samples):
            code = faker.swift11(primary=True)
            assert len(code) == 11
            assert code[8:11] == "XXX"


class TestFilPh(TestEnPh):
    """Test fil_PH bank provider"""

    pass


class TestTlPh(TestEnPh):
    """Test tl_PH bank provider"""

    pass


class TestTrTr:
    """Test tr_TR bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{22}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == TrTrBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{22}", iban[2:])


class TestDeCh:
    """Test de_CH bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{17}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == DeChBankProvider.country_code
            assert re.fullmatch(r"\d{19}", iban[2:])


class TestFrCh(TestDeCh):
    """Test fr_CH bank provider"""

    pass


class TestItCh(TestDeCh):
    """Test it_CH bank provider"""

    pass


class TestThTh:
    """Test th_TH bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{10}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == ThThBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{10}", iban[2:])


class TestElGr:
    """Test el_GR bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{23}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == ElGrBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{23}", iban[2:])


class TestEnIn:
    """Test en_IN bank provider"""

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"\D{7,25}", faker.bank())


class TestNlBe:
    """Test nl_BE bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{12}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == NlBeBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{12}", iban[2:])

    def test_swift8_use_dataset(self, faker, num_samples):
        for _ in range(num_samples):
            code = faker.swift8(use_dataset=True)
            assert len(code) == 8
            assert code[:4] in NlBeBankProvider.swift_bank_codes
            assert code[4:6] == NlBeBankProvider.country_code
            assert code[6:8] in NlBeBankProvider.swift_location_codes

    def test_swift11_use_dataset(self, faker, num_samples):
        for _ in range(num_samples):
            code = faker.swift11(use_dataset=True)
            assert len(code) == 11
            assert code[:4] in NlBeBankProvider.swift_bank_codes
            assert code[4:6] == NlBeBankProvider.country_code
            assert code[6:8] in NlBeBankProvider.swift_location_codes
            assert code[8:11] in NlBeBankProvider.swift_branch_codes


class TestZhCn:
    """Test zh_CN bank provider"""

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"[\u4e00-\u9fa5]{2,20}", faker.bank())



from .. import Provider as BaseProvider


class Provider(BaseProvider):
    jobs = [
        "Agent posredovanja u prometu nekretnina",
        "Alatničar",
        "Arhivist",
        "Arhivski savjetnik",
        "Arhivski tehničar",
        "Autoelektričar",
        "Autolakirer",
        "Autolimar",
        "Automehaničar",
        "Autoserviser",
        "Bravar",
        "Brodostrojarski inspektor",
        "Brodski mehaničar",
        "Dentalni asistent",
        "Dentalni tehničar",
        "Dimnjačar",
        "Diplomirana medicinska sestra/medicinski tehničar",
        "Diplomirani fizioterapeut",
        "Diplomirani knjižničar",
        "Diplomirani sanitarni inženjer",
        "Direktor predstavništva",
        "Direktor turističkog ureda turističke zajednice",
        "Dispečer leta / operativni kontrolor prometa",
        "Djelatnik koji obavlja poslove izvođenja glasnog pucnja",
        "Djelatnik koji obavlja poslove izvođenja javnog vatrometa",
        "Djelatnik koji obavlja poslove miniranja",
        "Djelatnik koji obavlja poslove miniranja pri razminiranju",
        "Djelatnik koji obavlja poslove podzemnih miniranja",
        "Djelatnik koji obavlja poslove pripreme miniranja",
        "Djelatnik koji obavlja poslove specijalnih miniranja",
        "Djelatnik službe za zaštitu od požara",
        "Djelatnik za obavljanje poslova zaštite od požara i unapređenje stanja zaštite od požara",
        "Doktor dentalne medicine",
        "Doktor dentalne medicine specijalist",
        "Doktor medicine",
        "Doktor medicine specijalist",
        "Dokumentarist",
        "Dokumentarist savjetnik",
        "Dočasnik",
        "Edukacijski rehabilitator",
        "Elektroinstalater",
        "Elektromehaničar",
        "Elektroničar – mehaničar",
        "Farmaceutski tehničar",
        "Fasader",
        "Fizioterapeutski tehničar",
        "Fotograf",
        "Frizer",
        "Galanterist",
        "Geološki tehničar",
        "Glavni inspektor zaštite okoliša",
        "Glavni nadzornik",
        "Glazbalar",
        "Graditelj brodova",
        "Graditelj orgulja",
        "Hidrograđevinski  inspektor",
        "Informatičar",
        "Informatičar savjetnik",
        "Inspektor sigurnosti unutarnje plovidbe",
        "Inspektor zaštite okoliša",
        "Inspektor zaštite prirode",
        "Instalater grijanja i klimatizacije",
        "Instruktor vožnje",
        "Inženjer geologije",
        "Inženjer gradilišta",
        "Inženjer medicinske radiologije",
        "Inženjer medicinsko- laboratorijske dijagnostike",
        "Inženjer naftnog rudarstva",
        "Inženjer rudarstva",
        "Kemijski čistač",
        "Klesar",
        "Klobučar",
        "Knjižničar",
        "Knjižničarski savjetnik",
        "Kondukter",
        "Kontrolor zračnog prometa",
        "Konzervator",
        "Konzervator savjetnik",
        "Konzervator tehničar",
        "Konzervator – restaurator savjetnik",
        "Konzervator –  restaurator",
        "Koordinator zaštite na radu",
        "Kormilar",
        "Kotlar",
        "Kovač",
        "Kozmetičar",
        "Kriminalist",
        "Krojač muške odjeće",
        "Krojač ženske odjeće",
        "Krovopokrivač",
        "Krznar",
        "Kuhar",
        "Kustos",
        "Lektor hrvatskog jezika na stranim visokoškolskim ustanovama",
        "Limar",
        "Ljekarnik",
        "Ljekarnik specijalist",
        "Ljevač",
        "Lovac",
        "Lovočuvar",
        "Magistar sanitarnog inženjerstva",
        "Magistar sestrinstva",
        "Maser – kupeljar",
        "Medicinska sestra opće njege",
        "Medicinska sestra-medicinski tehničar",
        "Medicinska sestra/medicinski tehničar specijalist",
        "Medicinski biokemičar",
        "Medicinski biokemičar specijalist",
        "Mehaničar poljoprivredne mehanizacije",
        "Mesar",
        "Mlinar",
        "Mljekar",
        "Mornar",
        "Muzejski pedagog",
        "Muzejski pedagog savjetnik",
        "Muzejski savjetnik",
        "Muzejski tehničar",
        "Nadzornik",
        "Nadzornik tehničke ispravnosti vozila",
        "Nadzornik za okoliš",
        "Nastavnik predmetne nastave u srednjoj školi",
        "Natkonobar",
        "Nautički inspektor",
        "Obućar",
        "Ocjenjivač lovačkih trofeja",
        "Odgajatelj u učeničkom domu",
        "Odgojitelj djece predškolske dobi",
        "Odgovorna osoba za ocjenjivanje sukladnosti građevinskih proizvoda",
        "Odvjetnik",
        "Ortopedski obućar",
        "Osoba koja provodi energetske preglede građevina i/ili energetsko certificiranje zgrada",
        "Osoba stručno osposobljena za gospodarski ribolov",
        "Osoba stručno osposobljena za obavljanje akvakulture",
        "Osoba stručno osposobljena za uzgoj riba i drugih morskih organizama",
        "Osoblje za održavanje  zrakoplova (mehaničari, tehničari i inženjeri)",
        "Ovlaštena osoba za izradu elaborata zaštite od požara",
        "Ovlašteni arhitekt",
        "Ovlašteni arhitekt – urbanist",
        "Ovlašteni carinski službenik",
        "Ovlašteni carinski zastupnik",
        "Ovlašteni inženjer drvne tehnologije",
        "Ovlašteni inženjer elektrotehnike",
        "Ovlašteni inženjer geodezije",
        "Ovlašteni inženjer građevinarstva",
        "Ovlašteni inženjer strojarstva",
        "Ovlašteni inženjer tehnologije prometa i transporta",
        "Ovlašteni inženjer šumarstva",
        "Ovlašteni ispitivač",
        "Ovlašteni revident iz zaštite od požara",
        "Ovlašteni revizor",
        "Ovlašteni unutarnji revizor za javni sektor",
        "Očni optičar",
        "Pediker",
        "Pekar",
        "Pećar",
        "Pirotehničar",
        "Pirotehnički nadglednik",
        "Pirotehnički nadzornik",
        "Pismoslikar",
        "Plinoinstalater",
        "Policajac",
        "Pomoćni djelatnik",
        "Pomoćni knjižničar",
        "Pomoćnik strojovođe",
        "Porezni savjetnik",
        "Precizni mehaničar",
        "Predavač",
        "Pregledač vagona",
        "Preparator",
        "Primalja",
        "Primalja – asistentica",
        "Privatni detektiv",
        "Profesionalni diplomat",
        "Profesionalni pilot aviona",
        "Profesionalni pilot helikoptera",
        "Prometni pilot aviona",
        "Prometni pilot helikoptera",
        "Prometnik vlakova",
        "Prvostupnik fizioterapije",
        "Prvostupnik medicinske radiologije",
        "Prvostupnik medicinsko- laboratorijske dijagnostike",
        "Prvostupnik primaljstva",
        "Prvostupnik radiološke tehnologije",
        "Prvostupnik radne terapije",
        "Prvostupnik sanitarnog inženjerstva",
        "Prvostupnik sestrinstva",
        "Prvostupnik sestrinstva specijalist",
        "Psiholog",
        "Puškar",
        "Radio inspektor sigurnosti plovidbe",
        "Radiološki tehničar",
        "Radnik na stručnim poslovima na izvršenju zadaća turističke zajednice",
        "Radnik zaposlen na rukovodećim poslovima",
        "Ravnatelj ustanove za predškolski odgoj i naobrazbu",
        "Ravnatelj školske ustanove",
        "Referent za poslove registracije vozila",
        "Restaurator",
        "Restaurator majstor",
        "Restaurator savjetnik",
        "Restaurator tehničar",
        "Revident",
        "Rudarski tehničar",
        "Rukovatelj eksplozivnim tvarima",
        "Rukovoditelj tehničkog plovila",
        "Sanitarni tehničar",
        "Sigurnosni savjetnik",
        "Slastičar",
        "Soboslikar – ličilac",
        "Socijalni radnik",
        "Sportski trener",
        "Sportski učitelj / instruktor",
        "Sportski voditelj",
        "Staklar",
        "Stalni sudski procjenitelj",
        "Stalni sudski tumač",
        "Stalni sudski vještak",
        "Stolar",
        "Strojar unutarnje plovidbe",
        "Strojobravar",
        "Strojovođa",
        "Strukovni učitelj u srednjoj školi",
        "Stručni radnik u djelatnosti socijalne skrbi",
        "Stručni radnik u ustanovi socijalne skrbi",
        "Stručni suradnik ovlaštenog inženjera geodezije",
        "Stručni suradnik u predškolskoj ustanovi",
        "Stručni suradnik u školskoj ustanovi",
        "Stručni voditelj autoškole",
        "Stručnjak zaštite na radu",
        "Suradnik ovlaštenog inženjera geodezije",
        "Suradnik u nastavi",
        "Tapetar",
        "Tesar",
        "Tokar",
        "Turistički pratitelj",
        "Turistički vodič",
        "Upravitelj prijevoza (osoba odgovorna za prijevoz)",
        "Urar",
        "Učitelj predmetne nastave u osnovnoj školi",
        "Učitelj razredne nastave u osnovnoj školi",
        "Učitelj stručnih predmeta",
        "Veterinar",
        "Veterinarski tehničar",
        "Viši arhivist",
        "Viši arhivski tehničar",
        "Viši dokumentarist",
        "Viši fotograf",
        "Viši informatičar",
        "Viši inspektor",
        "Viši inspektor cestovnog prometa i cesta",
        "Viši inspektor zaštite okoliša",
        "Viši inspektor zaštite prirode",
        "Viši knjižničar",
        "Viši konzervator",
        "Viši konzervator tehničar",
        "Viši konzervator tehničar II stupnja",
        "Viši konzervator –  restaurator",
        "Viši kustos",
        "Viši muzejski pedagog",
        "Viši muzejski tehničar",
        "Viši preparator",
        "Viši restaurator",
        "Viši restaurator tehničar",
        "Vlakovođa",
        "Voditelj ispostave",
        "Voditelj poslovnice turističke agencije",
        "Voditelj projekta",
        "Voditelj radilišta",
        "Voditelj radova",
        "Voditelj skele u nacionalnoj plovidbi",
        "Vodoinstalater",
        "Vodoinstalater, instalater grijanja i klimatizacije",
        "Vojnik",
        "Vozač teretnog motornog vozila i autobusa",
        "Vođa palube",
        "Zapovjednik plovila (vrsta A, vrsta B, vrsta C)",
        "Zaštitar",
        "Zaštitar-tehničar",
        "Zdravstveno laboratorijski tehničar",
        "Zidar",
        "Zlatar",
        "Časnik",
        "Član kabinske posade zrakoplova",
        "Čuvar",
        "Čuvar prirode",
    ]



from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``uk_UA`` locale."""

    word_list = (
        "увійти",
        "монета",
        "підкинути",
        "бажання",
        "іспит",
        "податковий",
        "витягувати",
        "приятель",
        "здригатися",
        "купа",
        "порт",
        "точно",
        "заплакати",
        "хата",
        "правління",
        "художній",
        "болісно",
        "зображати",
        "ліхтарик",
        "міф",
        "сумний",
        "небезпека",
        "міра",
        "пастух",
        "факультет",
        "мигнути",
        "польовий",
        "інший",
        "виражений",
        "забирати",
        "рот",
        "народ",
        "відповідність",
        "тута",
        "комунізм",
        "рішення",
        "плід",
        "співрозмовник",
        "обуритися",
        "гідність",
        "господь",
        "болото",
        "інфекція",
        "голубчик",
        "синок",
        "простір",
        "прощення",
        "раніше",
        "хотіти",
        "ленінград",
        "даль",
        "розвинений",
        "близько",
        "більше",
        "спорт",
        "епоха",
        "відповісти",
        "звільнити",
        "порада",
        "прохід",
        "палець",
        "вчора",
        "пристойний",
        "яскраво",
        "білизна",
        "коваль",
        "несподівано",
        "вперед",
        "зате",
        "кільце",
        "перед",
        "мить",
        "плавно",
        "тютюн",
        "число",
        "вивчити",
        "важкий",
        "міркування",
        "салон",
        "ідея",
        "що",
        "світило",
        "порода",
        "сумнівний",
        "бок",
        "очко",
        "незручно",
        "радити",
        "відділ",
        "помовчати",
        "вітати",
        "пробувати",
        "дошлий",
        "сміятися",
        "наполегливо",
        "здригнутися",
        "затягнутися",
        "танцювати",
        "пісенька",
        "вибирати",
        "правильний",
        "намір",
        "здалеку",
        "запустити",
        "насолода",
        "щур",
        "летіти",
        "космос",
        "радість",
        "поїзд",
        "знаходити",
        "гуляти",
        "гіркий",
        "бочок",
        "ніч",
        "щастя",
        "знищення",
        "диявол",
        "коробка",
        "спасти",
        "шкіра",
        "провінція",
        "прелесть",
        "в'язниця",
        "вечір",
        "низький",
        "виблискувати",
        "темніти",
        "сонце",
        "гараж",
        "червʼяк",
        "дружно",
        "настати",
        "блін",
        "степ",
        "самостійно",
        "крутий",
        "картинка",
        "навіщо",
        "робочий",
        "незвичайний",
        "армійський",
        "труп",
        "ягода",
        "близько",
        "монета",
        "природний",
        "юний",
        "район",
        "прихований",
        "зловити",
        "будівництво",
        "палата",
        "мить",
        "триста",
        "штаб",
        "ламати",
        "можливо",
        "полюбити",
        "чоловічок",
        "легко",
        "почуття",
        "струмок",
        "кишеня",
        "гроші",
        "неправда",
        "порівняння",
        "груди",
        "від'їзд",
        "виникнення",
        "степ",
        "збудження",
        "діловий",
        "отже",
        "рідкий",
        "синок",
        "художній",
        "покоління",
        "розстебнути",
        "їжа",
        "вчений",
        "секунда",
        "заспокоїтися",
        "навряд",
        "аж",
        "вскакивать",
        "мимо",
        "падати",
        "потягнутися",
        "загроза",
        "розгубитися",
        "бігати",
        "склянка",
        "о",
        "кпсс",
        "нині",
        "підлога",
        "реклама",
        "при",
        "шкільний",
        "прем'єра",
        "дальній",
        "потрясти",
        "звільнення",
        "покидати",
        "наступати",
        "жити",
        "який",
        "образа",
        "командування",
        "дівка",
        "висловлюватися",
        "головний",
        "другий",
        "князь",
        "соціалістичний",
        "головка",
        "залучати",
        "через",
        "господь",
        "результат",
        "відзначити",
        "адже",
        "падаль",
        "покидати",
        "художній",
        "правий",
        "висіти",
        "лапа",
        "каюта",
        "занадто",
        "нервово",
        "серйозний",
        "зима",
        "заробити",
        "ефект",
        "прірва",
        "плід",
        "щось",
        "що-небудь",
        "казна-хто",
        "висіти",
        "холодно",
        "єдиний",
        "викинути",
        "похмуро",
        "вигнати",
        "вмирати",
        "інший",
        "космос",
        "природа",
        "функція",
        "поставити",
        "оборот",
        "услати",
        "черговий",
        "медицина",
        "функція",
        "зарплата",
        "витримати",
        "розлад",
        "адвокат",
        "затримати",
        "поява",
        "інвалід",
        "інтелектуальний",
        "досліджено",
        "мати",
        "ліворуч",
        "хлопець",
        "мільярд",
        "гіркий",
        "трубка",
        "подробиця",
        "паща",
        "незвичний",
        "угодний",
        "засунути",
        "мета",
        "заборонити",
        "дрімати",
        "розуміти",
        "приходити",
        "нарада",
        "постійний",
        "аналіз",
        "терапія",
        "приятель",
        "процес",
        "академік",
        "метал",
        "розвернутися",
        "жорстокий",
        "інтернет",
        "яблуко",
        "банда",
        "зміна",
        "колектив",
        "похорон",
        "пристрій",
        "квапливий",
        "розводити",
        "промовчати",
        "підземний",
        "полум'я",
        "редактор",
        "теорія",
        "олівець",
        "упор",
        "означати",
        "метелик",
        "чотири",
        "століття",
        "різноманітний",
        "вітрина",
        "ніж",
        "команда",
        "шолом",
        "недолік",
        "протягувати",
        "за",
        "метал",
        "домогтися",
        "доба",
        "чітко",
        "надати",
        "тисяча",
        "заспівати",
        "бригада",
        "дрібниця",
        "виражений",
        "перетнути",
        "сходити",
        "взагалі",
        "рис",
        "банк",
        "бак",
        "передо",
        "призначити",
        "важливий",
        "правління",
        "палиця",
        "трясти",
        "упустити",
        "вітрина",
        "основа",
        "так",
        "мʼята",
        "пірʼя",
        "перебивати",
        "дихання",
        "застосовуватися",
        "червень",
        "бетонний",
        "уникати",
        "благати",
        "м'який",
        "заява",
        "конференція",
        "встати",
        "свіжий",
        "супроводжуватися",
        "ланцюжок",
        "вираз",
        "кут",
        "черевик",
        "лягати",
        "інструкція",
        "присісти",
        "решітка",
        "єврейський",
        "поріг",
        "зелений",
        "кордон",
        "ставити",
        "сміливий",
        "суглоб",
        "роса",
        "демократія",
        "вивести",
        "конструкція",
        "задерти",
        "багряний",
        "військовий",
        "направо",
        "житель",
        "товар",
        "солома",
        "ґазда",
        "ґаздиня",
        "ґудзик",
        "неправда",
        "матерія",
        "командувач",
        "кидати",
        "закласти",
        "ліловий",
        "слати",
        "гіркий",
        "простір",
        "провал",
        "сміття",
        "наштовхнутися",
        "торгівля",
        "монета",
        "місце",
        "спалити",
        "брову",
        "лівий",
        "хліб",
        "коричневий",
        "подвірʼя",
        "потім",
        "червонй",
        "пристрасть",
        "виднітися",
        "розкішний",
        "спосіб",
        "багаття",
        "заклад",
        "пропадати",
        "занадто",
        "п'ятеро",
        "програміст",
        "кора",
        "хлопчисько",
        "тьмяний",
        "несподіваний",
        "танцювати",
        "безглуздий",
        "здригнутися",
        "скинути",
        "прошепотіти",
        "безпорадний",
        "рота",
        "пісня",
        "тривога",
        "деякий",
        "термін",
        "пити",
        "колишній",
        "натиснути",
        "видимо",
        "валюта",
        "набір",
        "боєць",
        "райком",
        "новий",
        "ковзати",
        "керівник",
        "вовк",
        "зрідка",
        "зрозумілий",
        "пропаганда",
        "зупинити",
        "виконувати",
        "хід",
        "пані",
        "друкувати",
        "командир",
        "знімати",
        "страта",
        "ручка",
        "камінчик",
        "нога",
        "нестерпний",
        "спорт",
        "тривога",
        "уточнити",
        "актриса",
        "повністю",
        "покинути",
        "блискучий",
        "мотоцикл",
        "дорогий",
        "вказаний",
        "ремінь",
        "присвятити",
        "один",
        "а",
        "їсти",
        "діставати",
        "господиня",
        "шкарпетка",
        "написати",
        "єврейський",
        "заклик",
        "збільшуватися",
        "байдужий",
        "грати",
        "співати",
        "й",
        "фахівець",
        "купа-невеличка",
    )

    parts_of_speech: Dict[str, tuple] = {}



from .. import Provider as MiscProvider


class Provider(MiscProvider):
    """
    Provider for miscellaneous data for en_PH locale

    This class also houses all other provider methods that would have otherwise been weird to place in another provider.
    """

    gemstone_names = (
        "Agate",
        "Amber",
        "Amethyst",
        "Aquamarine",
        "Citrine",
        "Diamond",
        "Emerald",
        "Garnet",
        "Jade",
        "Jasper",
        "Lapis Lazuli",
        "Moonstone",
        "Onyx",
        "Opal",
        "Peridot",
        "Ruby",
        "Sapphire",
        "Sardonyx",
        "Sunstone",
        "Topaz",
        "Turquoise",
        "Zircon",
    )
    mountain_names = (
        "Apo",
        "Arayat",
        "Atok",
        "Banahaw",
        "Bulusan",
        "Caraballo",
        "Cordillera",
        "Cresta",
        "Halcon",
        "Hibok-Hibok",
        "Iriga",
        "Kanlaon",
        "Makiling",
        "Malinao",
        "Mariveles",
        "Matumtum",
        "Mayon",
        "Palali",
        "Palanan",
        "Pao",
        "Pinatubo",
        "Samat",
        "Sicaba",
        "Sierra Madre",
        "Tabayoc",
    )
    plant_names = (
        "Acacia",
        "Agoho",
        "Akle",
        "Anahaw",
        "Anonas",
        "Anubing",
        "Aranga",
        "Asparagus",
        "Atis",
        "Avocado",
        "Azalea",
        "Azucena",
        "Bagtikan",
        "Bakawan",
        "Balete",
        "Balimbing",
        "Banaba",
        "Banuyo",
        "Banyan",
        "Baticulin",
        "Batino",
        "Bauhinia",
        "Bouganvilla",
        "Caballero",
        "Cabbage",
        "Calantas",
        "Calumpang",
        "Camachile",
        "Camia",
        "Campanilla",
        "Carissa",
        "Carrot",
        "Catmon",
        "Cattleya",
        "Cauliflower",
        "Celery",
        "Champaca",
        "Chico",
        "Coconut",
        "Cucumber",
        "Cypress",
        "Dao",
        "Dapdap",
        "Dita",
        "Duhat",
        "Dungon",
        "Gladiola",
        "Gloriosa",
        "Granada",
        "Guijo",
        "Gumamela",
        "Intsia",
        "Ipil",
        "Jacaranda",
        "Jasmine",
        "Kaimito",
        "Kalachuchi",
        "Kalamansi",
        "Kamagong",
        "Kamias",
        "Lanzones",
        "Lawaan",
        "Lily",
        "Lumbayao",
        "Mabolo",
        "Macapuno",
        "Macopa",
        "Magnolia",
        "Mahogany",
        "Malugay",
        "Mayapis",
        "Melon",
        "Milflower",
        "Molave",
        "Mushroom",
        "Mustard",
        "Narra",
        "Nipa",
        "Oleander",
        "Oliva",
        "Orchid",
        "Palm",
        "Pandan",
        "Pepper",
        "Piña",
        "Raddish",
        "Rosas",
        "Sampaguita",
        "Sampaloc",
        "Santan",
        "Santol",
        "Sineguelas",
        "Squash",
        "Supa",
        "Talisay",
        "Tamarind",
        "Tanguile",
        "Tindalo",
        "Tulip",
        "Yakal",
        "Zinia",
    )
    space_object_names = (
        "Andromeda",
        "Antares",
        "Aquarius",
        "Aries",
        "Asteroid",
        "Cancer",
        "Canopus",
        "Capricorn",
        "Comet",
        "Constellation",
        "Earth",
        "Galaxy",
        "Gemini",
        "Hercules",
        "Hydra",
        "Juno",
        "Jupiter",
        "Leo",
        "Libra",
        "Mars",
        "Mercury",
        "Milky Way",
        "Neptune",
        "Orion",
        "Pisces",
        "Planet",
        "Pluto",
        "Polaris",
        "Sagittarius",
        "Saturn",
        "Scorpio",
        "Taurus",
        "Uranus",
        "Venus",
        "Virgo",
        "Zodiac",
    )
    random_object_names = gemstone_names + mountain_names + plant_names + space_object_names

    def gemstone_name(self) -> str:
        return self.random_element(self.gemstone_names)

    def mountain_name(self) -> str:
        return self.random_element(self.mountain_names)

    def plant_name(self) -> str:
        return self.random_element(self.plant_names)

    def space_object_name(self) -> str:
        return self.random_element(self.space_object_names)

    def random_object_name(self) -> str:
        return self.random_element(self.random_object_names)



from .. import Provider as BaseProvider


class Provider(BaseProvider):
    jobs = (
        "Ակադեմիական գրադարանավար",
        "Հաշվապահ",
        "Դերասան",
        "Ասեղնաբույժ",
        "Ադմինիստրատոր",
        "Ավիացիոն ինժեներ",
        "Գյուղատնտեսական խորհրդատու",
        "Գյուղատնտեսական տեխնիկ",
        "Օդային երթևեկության վերահսկիչ",
        "Ավիաուղիների օդաչու",
        "Անիմատոր",
        "Հնագետ",
        "Ճարտարապետ",
        "Ճարտարապետական տեխնոլոգ",
        "Արխիվարիուս",
        "Զինված ուժերի տեխնիկական սպասարկող",
        "Զինված ուժերի ուսուցման և կրթության սպա",
        "Արվեստի պատկերասրահի կառավարիչ",
        "Արվեստագետ",
        "Դոցենտ",
        "Աստղագետ",
        "Աուդիո գիտնական",
        "Բանկիր",
        "Կենսաքիմիկոս",
        "Կենսաբժշկական ինժեներ",
        "Կենսաբժշկական գիտնական",
        "Պարտատոմսերի վաճառող",
        "Գրավաճառ",
        "Շինհրապարակի տեսուչ",
        "Շինությունների սպասարկման ինժեներ",
        "Սպասարկման կենտրոնի մենեջեր",
        "Օպերատոր",
        "Քարտեզագրիչ",
        "Քեյթերինգի մենեջեր",
        "Կերամիկայի դիզայներ",
        "Քիմիական ինժեներ",
        "Քիմիկոս",
        "Գլխավոր գործադիր տնօրեն",
        "Գլխավոր ֆինանսական տնօրեն",
        "Գլխավոր մարքեթինգային պատասխանատու",
        "Անձնակազմի ղեկավար",
        "Գործադիր տնօրեն",
        "Գլխավոր ռազմավարության պատասխանատու",
        "Գլխավոր տեխնոլոգիաների պատասխանատու",
        "Մանկական հոգեթերապևտ",
        "Կիրոպրատոր",
        "Քաղաքացիական ինժեներ",
        "Քաղաքացիական ծառայության վարչարար",
        "Կլինիկական կենսաքիմիկոս",
        "Կլինիկական ցիտոգենիկիստ",
        "Կլինիկական մոլեկուլային գենետիկ",
        "Կլինիկական հոգեբան",
        "Կոմերցիոն արվեստի պատկերասրահի ղեկավար",
        "Կապի ինժեներ",
        "Ընկերության քարտուղար",
        "Համակարգչային խաղեր մշակող",
        "Կոնֆերանսի կենտրոնի ղեկավար",
        "Կապալառու",
        "Կորպորատիվ ներդրումային բանկիր",
        "Կորպորատիվ գանձապահ",
        "Խորհրդատու հոգեբան",
        "Խորհրդատու",
        "Կուրատոր",
        "Հաճախորդների սպասարկման կառավարիչ",
        "Պարող",
        "Տվյալների մշակման մենեջեր",
        "Տվյալների գիտնական",
        "Տվյալների շտեմարանի կառավարիչ",
        "Դիլեր",
        "Ատամնաբույժ",
        "Վիտրաժների դիզայներ",
        "Կերամիկայի դիզայներ",
        "Ցուցահանդեսի դիզայներ",
        "Ոճաբան",
        "Կահույքի դիզայներ",
        "Գրաֆիկական դիզայներ",
        "Արդյունաբերական դիզայներ",
        "Ինտերիերի դիզայներ",
        "Զարդերի դիզայներ",
        "Մուլտիմեդիա դիզայներ",
        "Ֆիլմի դիզայներ",
        "Տեքստիլ դիզայներ",
        "Բնապահպան",
        "Տնտեսագետ",
        "Կրթական հոգեբան",
        "Էլեկտրատեխնիկ",
        "Էլեկտրոնիկայի ինժեներ",
        "Ավիացիոն ինժեներ",
        "Գյուղատնտեսական ինժեներ",
        "Ավտոմեքենայի ինժեներ",
        "Կենսաբժշկական ինժեներ",
        "Շինությունների սպասարկման ինժեներ",
        "Քիմիական ինժեներ",
        "Քաղաքացիական ինժեներ",
        "Կապի ինժեներ",
        "Հորատման ինժեներ",
        "Արտադրության համակարգերի ինժեներ",
        "Հանքարդյունաբերության ինժեներ",
        "Նավթային ինժեներ",
        "Երկրաբանական  ինժեներ",
        "Բնապահպանական խորհրդատու",
        "Բաժնետոմսերի վաճառող",
        "Էրգոնոմիստ",
        "Անշարժ գույքի գործակալ",
        "Միջոցառումների կազմակերպիչ",
        "Ցուցահանդեսի դիզայներ",
        "Դաշտային սեյսմոլոգ",
        "Ֆինանսական խորհրդատու",
        "Ֆինանսական վերահսկիչ",
        "Ֆինանսական մենեջեր",
        "Ֆինանսական պլանավորող",
        "Ֆինանսական ռիսկի վերլուծաբան",
        "Նկարիչ",
        "Հրշեջ",
        "Ֆիտնես կենտրոնի ղեկավար",
        "Սննդի տեխնոլոգ",
        "Դատական հոգեբան",
        "Դատաբժշկական գիտնական",
        "Տեքստիլ տեխնոլոգ",
        "Մոլեկուլային գենետիկ",
        "Երկրաբան",
        "Ապակեգործ",
        "Հեմատոլոգ",
        "Առողջության և անվտանգության հարցերով խորհրդատու",
        "Առողջապահության և անվտանգության տեսուչ",
        "Ֆիզիկոս",
        "Առողջության խթանման մասնագետ",
        "Առողջապահական ծառայությունների ղեկավար",
        "Հերտոլոգ",
        "Բարձրագույն կրթության կարիերայի խորհրդատու",
        "Պատմական շենքերի պահպանման մասնագետ",
        "Այգեգործության խորհրդատու",
        "Այգեգործ",
        "Հիվանդանոցի բժիշկ",
        "Հյուրանոցի կառավարիչ",
        "Մարդկային ռեսուրսների մասնագետ",
        "Հիդրոէկոլոգ",
        "Հիդրոգրաֆիկ հետազոտող",
        "Հիդրոլոգ",
        "Իմունոլոգ",
        "Տեղեկատվական աշխատող",
        "Տեղեկատվական համակարգերի կառավարիչ",
        "Ապահովագրության հաշվի կառավարիչ",
        "Ապահովագրական բրոքեր",
        "Ապահովագրական ռիսկերի հետազոտող",
        "Միջազգային օգնության աշխատող",
        "Թարգմանիչ",
        "Ներդրումային վերլուծաբան",
        "Ներդրումային բանկիր",
        "ՏՏ խորհրդատու",
        "ՏՏ վաճառքի մասնագետ",
        "Լրագրող",
        "Լանդշաֆտի ճարտարապետ",
        "Իրավաբան",
        "Փաստաբան",
        "Դասախոս",
        "Իրավական քարտուղար",
        "Ժամանցի կենտրոնի կառավարիչ",
        "Բառարանագիր",
        "Գրադարանավար",
        "Լուսավորման տեխնիկ",
        "Լոբբիստ",
        "Լոգիստիկայի և բաշխման մենեջեր",
        "Ամսագրի լրագրող",
        "Տեխնիկական սպասարկման մասնագետ",
        "Կառավարման խորհրդատու",
        "Արտադրության համակարգերի ինժեներ",
        "Շուկայի հետազոտող",
        "Մեխանիկական ինժեներ",
        "Հոգեկան առողջության բուժքույր",
        "Մետաղագործ",
        "Միկրոբիոլոգ",
        "Մանկաբարձուհի",
        "Հանքանյութերի հետազոտող",
        "Հանքարդյունաբերող",
        "Մուլտիմեդիայի ծրագրավորող",
        "Մուլտիմեդիայի մասնագետ",
        "Երաժշտության դասախոս",
        "Երաժիշտ",
        "Ցանցային ինժեներ",
        "Նյարդավիրաբույժ",
        "Բուժքույր",
        "Գրասենյակի մենեջեր",
        "Ուռուցքաբան",
        "Ակնաբույժ",
        "Օպտոմետրիստ",
        "Օրթոպիստ",
        "Օստեոպաթ",
        "Մանկական բուժքույր",
        "Պարամեդիկ",
        "Ուղևորափոխադրումների մենեջեր",
        "Արտոնագրային հավատարմատար",
        "Պաթոլոգ",
        "Անձնական օգնական",
        "Դեղագործ",
        "Դեղագետ",
        "Լուսանկարիչ",
        "Ֆիզիոլոգ",
        "Ֆիզիոթերապևտ",
        "Ֆիտոթերապևտ",
        "Գենետիկ",
        "Պոդիոնիստ",
        "Ոստիկան",
        "Պրոդյուսեր",
        "Ապրանքի դիզայներ",
        "Արտադրանքի մենեջեր",
        "Ծրագրավորող",
        "Սրբագրիչ",
        "Հոգեբույժ",
        "Հոգեբան",
        "Հոգեթերապևտ",
        "Գնումների մենեջեր",
        "Որակի մենեջեր",
        "Ռադիոլոգ",
        "Պահակ",
        "Գիտաշխատող",
        "Ռեստորանի կառավարիչ",
        "Գիտական լաբորատորիայի տեխնիկ",
        "Դատաբժիշկ",
        "Հարկային տեսուչ",
        "Սոցիալական աշխատող",
        "Հավատարմատար",
        "Ձայնային տեխնիկ",
        "Խոսքի և լեզվի թերապևտ",
        "Մարզիչ",
        "Սպորտային թերապևտ",
        "Վիճակագրագետ",
        "Վիրաբույժ",
        "Բժիշկ",
        "Համակարգերի վերլուծաբան",
        "Հարկային խորհրդատու",
        "Ուսուցիչ",
        "Թերապևտիկ ռադիոլոգ",
        "Թերապևտ",
        "Տուր մենեջեր",
        "Թոքիկոլոգ",
        "Թարգմանիչ",
        "Տրանսպորտի պլանավորող",
        "Անասնաբույժ",
        "Պահեստապետ",
        "Թափոնների կառավարման պատասխանատու",
        "Ջրի որակի գիտնական",
        "Վեբ դիզայներ",
        "Գրող",
    )
